/**
 * SADX Mod Loader.
 * SADX enums based on symbols.
 */

#ifndef SADXMODLOADER_SADXENUMSNEW_H
#define SADXMODLOADER_SADXENUMSNEW_H

#include <stdint.h>

// SADX Enums

#define makemask(enumname,membername) enumname##_##membername = (1 << enumname##Bits_##membername)
#define makemasks(enumname,membername) enumname##s_##membername = (1 << enumname##Bits_##membername)
#define levelact(level, act) (((level) << 8) | (act))

enum TEX_EFF
{
	TEX_EFF_RING = 0x0,
	TEX_EFF_SMOKE = 0x8,
	TEX_EFF_BOMB = 0x10,
	TEX_EFF_EXP = 0x20,
	TEX_EFF_FLAME = 0x28,
	TEX_EFF_LENS = 0x32,
	TEX_EFF_PANLIGHT = 0x39,
	TEX_EFF_HIT = 0x3A,
	TEX_EFF_KIRAN = 0x42,
	TEX_EFF_LIGHTNING = 0x46,
	TEX_EFF_WATER = 0x4E,
	TEX_EFF_ROCKET = 0x56,
	TEX_EFF_SNOW = 0x5E,
	TEX_EFF_TBARRIER = 0x66,
	TEX_EFF_NBARRIER = 0x71,
	TEX_EFF_MUTEKI = 0x79,
	TEX_EFF_PLEXPL = 0x81,
	TEX_EFF_BUBBLE = 0x82,
	TEX_EFF_PANJET = 0x83,
	TEX_EFF_HITMARK = 0x86,
	TEX_EFF_MUTEKIBALL = 0x87,
	NUM_TEX_EFF = 0x88,
};

enum TEX_CON
{
	TEX_CON_SNUM = 0x0,
	TEX_CON_HYOUJI = 0xB,
	TEX_CON_ZANKI = 0xC,
	TEX_CON_LEVEL = 0x14,
	TEX_CON_DIGIT = 0x18,
	TEX_CON_PAUSE = 0x23,
	TEX_CON_YNUM = 0x5B,
	TEX_CON_ZANKI_METALSONIC = 0x65,
	TEX_CON_MISSION_SLASH = 0x66,
	NUM_TEX_CON = 0x67,
};

enum tasklevel
{
	LEV_0 = 0x0,
	LEV_1 = 0x1,
	LEV_2 = 0x2,
	LEV_3 = 0x3,
	LEV_4 = 0x4,
	LEV_5 = 0x5,
	LEV_6 = 0x6,
	LEV_C = 0x7,
	LEV_M = 0x8,
};

enum PL_JOIN
{
	PL_JOIN_NO_JOIN = 0x0,
	PL_JOIN_AVE = 0x1,
	PL_JOIN_SRC = 0x2,
	PL_JOIN_DST = 0x3,
	PL_JOIN_RHAND_POS = 0x4,
	PL_JOIN_LHAND_POS = 0x5,
	PL_JOIN_RFOOT_POS = 0x6,
	PL_JOIN_LFOOT_POS = 0x7,
	PL_JOIN_USER0_POS = 0x8,
	PL_JOIN_USER1_POS = 0x9,
	PL_JOIN_END = 0xA,
};

enum MODE_JOIN
{
	MODE_JOIN_INIT = 0x0,
	MODE_JOIN_EXEC = 0x1,
	MODE_JOIN_END = 0x2,
};

enum OBJ_JOIN
{
	OBJ_JOIN_NO_JOIN = 0x0,
	OBJ_JOIN_AVE = 0x1,
	OBJ_JOIN_SRC = 0x2,
	OBJ_JOIN_DST = 0x3,
};

enum ADV_PLNO
{
	ADV_PLNO_SONIC = 0x0,
	ADV_PLNO_TAILS = 0x1,
	ADV_PLNO_KNUCKLES = 0x2,
	ADV_PLNO_AMY = 0x3,
	ADV_PLNO_BIG = 0x4,
	ADV_PLNO_E102 = 0x5,
	ADV_PLNO_SUPER_SONIC = 0x6,
	NB_ADV_PLNO = 0x7,
};

enum SA_YesNoMaybe
{
	SA_No = 0xFFF0001,
	SA_Maybe = 0xFFF0010,
	SA_Yes = 0xFFF0100,
};

enum NED_PADMAP
{
	NED_PADMAP_DIJ_NONE = 0xFFFFFFFF,
	NED_PADMAP_DIJ_A = 0x0,
	NED_PADMAP_DIJ_B = 0x1,
	NED_PADMAP_DIJ_C = 0x2,
	NED_PADMAP_DIJ_X = 0x3,
	NED_PADMAP_DIJ_Y = 0x4,
	NED_PADMAP_DIJ_Z = 0x5,
	NED_PADMAP_DIJ_LEFT = 0x6,
	NED_PADMAP_DIJ_RIGHT = 0x7,
	NED_PADMAP_DIJ_ST = 0x8,
	NED_PADMAP_DIJ_KU = 0x9,
	NED_PADMAP_DIJ_KD = 0xA,
	NED_PADMAP_DIJ_KL = 0xB,
	NED_PADMAP_DIJ_KR = 0xC,
	NED_PADMAP_DIJ_MAX = 0xD,
};

enum KEYBTN_CODE
{
	KEYBTN_NULL = 0xFFFFFFFF,
	KEYBTN_ESCAPE = 0x0,
	KEYBTN_1 = 0x1,
	KEYBTN_2 = 0x2,
	KEYBTN_3 = 0x3,
	KEYBTN_4 = 0x4,
	KEYBTN_5 = 0x5,
	KEYBTN_6 = 0x6,
	KEYBTN_7 = 0x7,
	KEYBTN_8 = 0x8,
	KEYBTN_9 = 0x9,
	KEYBTN_0 = 0xA,
	KEYBTN_MINUS = 0xB,
	KEYBTN_EQUALS = 0xC,
	KEYBTN_BACK = 0xD,
	KEYBTN_TAB = 0xE,
	KEYBTN_Q = 0xF,
	KEYBTN_W = 0x10,
	KEYBTN_E = 0x11,
	KEYBTN_R = 0x12,
	KEYBTN_T = 0x13,
	KEYBTN_Y = 0x14,
	KEYBTN_U = 0x15,
	KEYBTN_I = 0x16,
	KEYBTN_O = 0x17,
	KEYBTN_P = 0x18,
	KEYBTN_LBRACKET = 0x19,
	KEYBTN_RBRACKET = 0x1A,
	KEYBTN_RETURN = 0x1B,
	KEYBTN_LCONTROL = 0x1C,
	KEYBTN_A = 0x1D,
	KEYBTN_S = 0x1E,
	KEYBTN_D = 0x1F,
	KEYBTN_F = 0x20,
	KEYBTN_G = 0x21,
	KEYBTN_H = 0x22,
	KEYBTN_J = 0x23,
	KEYBTN_K = 0x24,
	KEYBTN_L = 0x25,
	KEYBTN_SEMICOLON = 0x26,
	KEYBTN_APOSTROPHE = 0x27,
	KEYBTN_GRAVE = 0x28,
	KEYBTN_LSHIFT = 0x29,
	KEYBTN_BACKSLASH = 0x2A,
	KEYBTN_Z = 0x2B,
	KEYBTN_X = 0x2C,
	KEYBTN_C = 0x2D,
	KEYBTN_V = 0x2E,
	KEYBTN_B = 0x2F,
	KEYBTN_N = 0x30,
	KEYBTN_M = 0x31,
	KEYBTN_COMMA = 0x32,
	KEYBTN_PERIOD = 0x33,
	KEYBTN_SLASH = 0x34,
	KEYBTN_RSHIFT = 0x35,
	KEYBTN_MULTIPLY = 0x36,
	KEYBTN_LMENU = 0x37,
	KEYBTN_SPACE = 0x38,
	KEYBTN_CAPITAL = 0x39,
	KEYBTN_F1 = 0x3A,
	KEYBTN_F2 = 0x3B,
	KEYBTN_F3 = 0x3C,
	KEYBTN_F4 = 0x3D,
	KEYBTN_F5 = 0x3E,
	KEYBTN_F6 = 0x3F,
	KEYBTN_F7 = 0x40,
	KEYBTN_F8 = 0x41,
	KEYBTN_F9 = 0x42,
	KEYBTN_F10 = 0x43,
	KEYBTN_NUMLOCK = 0x44,
	KEYBTN_SCROLL = 0x45,
	KEYBTN_NUMPAD7 = 0x46,
	KEYBTN_NUMPAD8 = 0x47,
	KEYBTN_NUMPAD9 = 0x48,
	KEYBTN_SUBTRACT = 0x49,
	KEYBTN_NUMPAD4 = 0x4A,
	KEYBTN_NUMPAD5 = 0x4B,
	KEYBTN_NUMPAD6 = 0x4C,
	KEYBTN_ADD = 0x4D,
	KEYBTN_NUMPAD1 = 0x4E,
	KEYBTN_NUMPAD2 = 0x4F,
	KEYBTN_NUMPAD3 = 0x50,
	KEYBTN_NUMPAD0 = 0x51,
	KEYBTN_DECIMAL = 0x52,
	KEYBTN_OEM_102 = 0x53,
	KEYBTN_F11 = 0x54,
	KEYBTN_F12 = 0x55,
	KEYBTN_F13 = 0x56,
	KEYBTN_F14 = 0x57,
	KEYBTN_F15 = 0x58,
	KEYBTN_KANA = 0x59,
	KEYBTN_ABNT_C1 = 0x5A,
	KEYBTN_CONVERT = 0x5B,
	KEYBTN_NOCONVERT = 0x5C,
	KEYBTN_YEN = 0x5D,
	KEYBTN_ABNT_C2 = 0x5E,
	KEYBTN_NUMPADEQUALS = 0x5F,
	KEYBTN_PREVTRACK = 0x60,
	KEYBTN_AT = 0x61,
	KEYBTN_COLON = 0x62,
	KEYBTN_UNDERLINE = 0x63,
	KEYBTN_KANJI = 0x64,
	KEYBTN_STOP = 0x65,
	KEYBTN_AX = 0x66,
	KEYBTN_UNLABELED = 0x67,
	KEYBTN_NEXTTRACK = 0x68,
	KEYBTN_NUMPADENTER = 0x69,
	KEYBTN_RCONTROL = 0x6A,
	KEYBTN_MUTE = 0x6B,
	KEYBTN_CALCULATOR = 0x6C,
	KEYBTN_PLAYPAUSE = 0x6D,
	KEYBTN_MEDIASTOP = 0x6E,
	KEYBTN_VOLUMEDOWN = 0x6F,
	KEYBTN_VOLUMEUP = 0x70,
	KEYBTN_WEBHOME = 0x71,
	KEYBTN_NUMPADCOMMA = 0x72,
	KEYBTN_DIVIDE = 0x73,
	KEYBTN_SYSRQ = 0x74,
	KEYBTN_RMENU = 0x75,
	KEYBTN_PAUSE = 0x76,
	KEYBTN_HOME = 0x77,
	KEYBTN_UP = 0x78,
	KEYBTN_PRIOR = 0x79,
	KEYBTN_LEFT = 0x7A,
	KEYBTN_RIGHT = 0x7B,
	KEYBTN_END = 0x7C,
	KEYBTN_DOWN = 0x7D,
	KEYBTN_NEXT = 0x7E,
	KEYBTN_INSERT = 0x7F,
	KEYBTN_DELETE = 0x80,
	KEYBTN_LWIN = 0x81,
	KEYBTN_RWIN = 0x82,
	KEYBTN_APPS = 0x83,
	KEYBTN_POWER = 0x84,
	KEYBTN_SLEEP = 0x85,
	KEYBTN_WAKE = 0x86,
	KEYBTN_WEBSEARCH = 0x87,
	KEYBTN_WEBFAVORITES = 0x88,
	KEYBTN_WEBREFRESH = 0x89,
	KEYBTN_WEBSTOP = 0x8A,
	KEYBTN_WEBFORWARD = 0x8B,
	KEYBTN_WEBBACK = 0x8C,
	KEYBTN_MYCOMPUTER = 0x8D,
	KEYBTN_MAIL = 0x8E,
	KEYBTN_MEDIASELECT = 0x8F,
	KEYBTN_MAX = 0x90,
};

enum ALIFE_Mood
{
	ALIFE_NORMAL = 0x2,
	ALIFE_ANGRY = 0x6,
	ALIFE_JOY = 0x7,
	ALIFE_SING = 0x8,
	ALIFE_WORRY = 0x9,
	ALIFE_MERRY = 0xA,
};

enum AvaCharEnum
{
	AVA_SONIC = 0x0,
	AVA_MILES = 0x1,
	AVA_KNUCKLES = 0x2,
	AVA_AMY = 0x3,
	AVA_BIG = 0x4,
	AVA_E_102 = 0x5,
	AVA_SUPERSONIC = 0x6,
	AVA_METALSONIC = 0x6,
	AVA_CHAR_MAX = 0x7,
};

enum AdvaRetEnum
{
	ADVA_RETVALUE_SOFTRESET = 0xFFFFFFFE,
	ADVA_RETVALUE_CANCEL = 0xFFFFFFFF,
	ADVA_RETVALUE_ADVENTURE = 0x1,
	ADVA_RETVALUE_TRIAL = 0x64,
	ADVA_RETVALUE_SUMMARY = 0x65,
	ADVA_RETVALUE_MISSION = 0x66,
	ADVA_RETVALUE_ENDING = 0x67,
	ADVA_RETVALUE_TUTORIAL = 0x68,
	ADVA_RETVALUE_PLAYERSELECT = 0x69,
	ADVA_RETVALUE_KAKURE_SELECT = 0x6A,
	ADVA_RETVALUE_TITLE_TO_DEMO = 0x6B,
	ADVA_RETVALUE_SOFTRESET_IN_TITLE = 0x6C,
	ADVA_RETVALUE_TUTORIAL_CHSEL = 0x6D,
	ADVA_RETVALUE_MAX = 0x6E,
};

enum AdvaModeEnum
{
	ADVA_MODE_NONE = 0x0,
	ADVA_MODE_CHAR_SEL = 0x1,
	ADVA_MODE_FILE_SEL = 0x2,
	ADVA_MODE_TRIALACT_SEL = 0x3,
	ADVA_MODE_SND_TEST = 0x4,
	ADVA_MODE_TITLE_NEW = 0x5,
	ADVA_MODE_TITLE_MENU = 0x6,
	ADVA_MODE_OPTION_SEL = 0x7,
	ADVA_MODE_EXPLAIN = 0x8,
	ADVA_MODE_MINIGAME_SEL = 0x9,
	ADVA_MODE_EMBLEMVIEW = 0xA,
	ADVA_MODE_INETDEMO = 0xB,
	ADVA_MODE_TVSETTING = 0xC,
	ADVA_MODE_PUTI = 0xD,
	ADVA_MODE_TITLE_MENU_SUB = 0xE,
	ADVA_MODE_TITLE_MENU_LB = 0xF,
	ADVA_MODE_UN_TRIAL_GAME = 0x10,
	ADVA_MODE_UN_LEAD_BORADS = 0x11,
	ADVA_MODE_UN_ACHIVEMENT = 0x12,
	ADVA_MODE_OPTION_MENU_SUB = 0x13,
	ADVA_MODE_HOW_TO_PLAY = 0x14,
	ADVA_MODE_HOW_TO_PLAY2 = 0x15,
	ADVA_MODE_LB_MENU = 0x16,
	ADVA_MODE_OP_CREDITS = 0x17,
	ADVA_MODE_VANISH = 0x18,
	ADVA_MODE_END = 0x19,
	ADVA_MODE_END2 = 0x1A,
	ADVA_MODE_MAX = 0x1B,
};

enum SHAPE
{
	SHAPE_GEROGERO = 0x0,
	SHAPE_PUKUPUKU = 0x1,
	SHAPE_TAILOFF = 0x2,
	DUMMY1 = 0x3,
	SHAPE_TAILON = 0x4,
	DUMMY2 = 0x5,
	SHAPE_PUKU = 0x6,
	RESTORE = 0x7,
};

enum FACE
{
	FACE_KIHON1 = 0x0,
	FACE_KIHON2 = 0x1,
	FACE_KAIWA1 = 0x2,
	FACE_KAIWA2 = 0x3,
	FACE_KAIWA3 = 0x4,
	FACE_KAIWA4 = 0x5,
	FACE_KAIWA5 = 0x6,
	FACE_ODOROKI1 = 0x7,
	FACE_ODOROKI2 = 0x8,
	FACE_ODOROKI3 = 0x9,
	FACE_MEWOTOZIRU1 = 0xA,
	FACE_MEWOTOZIRU2 = 0xB,
	FACE_ODOROKI4 = 0xC,
	FACE_HUAN1 = 0xD,
	FACE_HUAN2 = 0xE,
	FACE_WARAI1 = 0xF,
	FACE_WARAI2 = 0x10,
	FACE_IKIZUKAI1 = 0x11,
	FACE_IKIZUKAI2 = 0x12,
	FACE_UTAGAU = 0x13,
	FACE_MEWOTOZIRU3 = 0x14,
	FACE_NERU = 0x15,
	FACE_UTURAUTURA = 0x16,
	FACE_OKIRU = 0x17,
	FACE_NEMUI = 0x18,
	FACE_ODOROKIKATAMARI = 0x19,
	FACE_KOMARI = 0x1A,
	FACE_WARAIKATAMARI = 0x1B,
	FACE_KATAMARI1 = 0x1C,
	FACE_KATAMARI2 = 0x1D,
	FACE_ODOROKIKATAMARI3SEC = 0x1E,
	FACE_EXPRESSION_NUMBER = 0x1F,
};

enum STAGE
{
	STAGE_NO = 0x0,
	STAGE_BEACH = 0x1,
	STAGE_WINDY = 0x2,
	STAGE_TWINKLEPARK = 0x3,
	STAGE_HIGHWAY = 0x4,
	STAGE_MOUNTAIN = 0x5,
	STAGE_SKYDECK = 0x6,
	STAGE_RUIN = 0x7,
	STAGE_SNOW = 0x8,
	STAGE_CASINO = 0x9,
	STAGE_FINAL = 0xA,
	STAGE_MUSHROOM = 0xB,
	STAGE_SHELTER = 0xC,
	STAGE_JUNGLE = 0xD,
	STAGE_DESART = 0xE,
	STAGE_CHAOS0 = 0xF,
	STAGE_CHAOS2 = 0x10,
	STAGE_CHAOS4 = 0x11,
	STAGE_CHAOS6 = 0x12,
	STAGE_CHAOS7 = 0x13,
	STAGE_EGGMOBILE1 = 0x14,
	STAGE_EGGMOBILE2 = 0x15,
	STAGE_EGGMOBILE3 = 0x16,
	STAGE_EGGMANROBO = 0x17,
	STAGE_E101 = 0x18,
	STAGE_E101_R = 0x19,
	STAGE_SS_AFT = 0x1A,
	STAGE_SS_EVE = 0x1B,
	STAGE_SS_NIG = 0x1C,
	STAGE_EC_ST_AB = 0x1D,
	STAGE_EC_ME_A = 0x1E,
	STAGE_EC_ME_B = 0x1F,
	STAGE_EC_C = 0x20,
	STAGE_MR = 0x21,
	STAGE_PAST = 0x22,
	STAGE_MG_CART = 0x23,
	STAGE_SHOOTING = 0x24,
	STAGE_SHOOTING2 = 0x25,
	STAGE_SANDBOARD = 0x26,
	STAGE_AL_GARDEN00_SS = 0x27,
	STAGE_AL_GARDEN01_EC = 0x28,
	STAGE_AL_GARDEN02_MR = 0x29,
	STAGE_AL_RACE = 0x2A,
	STAGE_NUMBER = 0x2B,
};

enum SSVAR
{
	SSVAR_HOTEL_KEYBLOCK = 0x0,
	SSVAR_CAR_DISP = 0x1,
	SSVAR_TWINKLE_ELEVATOR = 0x2,
	SSVAR_EGG_ON_STAND = 0x3,
	SSVAR_OFFICEDOOR_OPEN = 0x4,
	SSVAR_LIGHT_CONDITION = 0x5,
	SSVAR_NUM = 0x6,
};

enum MRVAR
{
	FLAG_MR_FIRST = 0x20,
	MRVAR_TORNADE_CATAPALT1 = 0x21,
	MRVAR_TORNADE_CATAPALT2 = 0x22,
	MRVAR_TORNADE_HATCH = 0x23,
	MRVAR_TORNADE2_HATCH = 0x24,
	MRVAR_MASTEREMERALD_STATE = 0x25,
	FLAG_MR_MAX = 0x26,
};

enum ECVAR
{
	FLAG_EC_FIRST = 0x20,
	FLAG_EC_JAIL1 = 0x21,
	FLAG_EC_JAIL2 = 0x22,
	FLAG_EC_JAIL3 = 0x23,
	FLAG_EC_POOL_CTRL = 0x24,
	FLAG_EC_ROTARYFLOOR_CTRL = 0x25,
	FLAG_EC_BRIDGE_CTRL = 0x26,
	FLAG_EC_MONORAIL_CTRL = 0x27,
	FLAG_EC_EGGMANBUTTON = 0x28,
	FLAG_EC_ELEVATOR_TOP = 0x29,
	FLAG_EC_ELEVATOR_BTM = 0x2A,
	FLAG_EC_GATE_A_CTRL = 0x2B,
	FLAG_EC_EGGLIFT_CTRL = 0x2C,
	FLAG_EC_MAX = 0x2D,
};

enum StoryFlags
{
	SSVAR_EGG_ON = 0x40,
	FLAG_SONIC_PLAYABLE = 0x41,
	FLAG_MILES_PLAYABLE = 0x42,
	FLAG_KNUCKLES_PLAYABLE = 0x43,
	FLAG_AMY_PLAYABLE = 0x44,
	FLAG_E102_PLAYABLE = 0x45,
	FLAG_BIG_PLAYABLE = 0x46,
	FLAG_SUPERSONIC_PLAYABLE = 0x47,
	FLAG_SONIC_COMPLETE = 0x48,
	FLAG_MILES_COMPLETE = 0x49,
	FLAG_KNUCKLES_COMPLETE = 0x4A,
	FLAG_AMY_COMPLETE = 0x4B,
	FLAG_E102_COMPLETE = 0x4C,
	FLAG_BIG_COMPLETE = 0x4D,
	FLAG_SUPERSONIC_COMPLETE = 0x4E,
	FLAG_GET_GOLDEGG = 0x4F,
	FLAG_GET_SILVEREGG = 0x50,
	FLAG_GET_BLACKEGG = 0x51,
	FLAG_SONIC_CHAO_GARDEN = 0x52,
	FLAG_MILES_CHAO_GARDEN = 0x53,
	FLAG_KNUCKLES_CHAO_GARDEN = 0x54,
	FLAG_AMY_CHAO_GARDEN = 0x55,
	FLAG_E102_CHAO_GARDEN = 0x56,
	FLAG_BIG_CHAO_GARDEN = 0x57,
	FLAG_PLAYING_SUPERSONIC = 0x58,
	FLAG_METALSONIC_PLAYABLE = 0x59,
	FLAG_SONIC_SS_BARRICADE = 0x80,
	FLAG_SONIC_SS_HOTEL_FRONT = 0x81,
	FLAG_SONIC_SS_STATION_FRONT = 0x82,
	FLAG_SONIC_SS_ENTRANCE_SEWER = 0x83,
	FLAG_SONIC_SS_EXIT_SEWER = 0x84,
	FLAG_SONIC_SS_ICESTONE = 0x85,
	FLAG_SONIC_SS_HOTEL_BACK = 0x86,
	FLAG_SONIC_SS_ENTRANCE_CASINO = 0x87,
	FLAG_SONIC_SS_STATION_BACK = 0x88,
	FLAG_SONIC_SS_TPARK_ELEVATOR = 0x89,
	FLAG_SONIC_SS_ENTRANCE_CIRCUIT = 0x8A,
	FLAG_SONIC_SS_CARD = 0x8B,
	FLAG_SONIC_SS_ENTRANCE_HIGHWAY = 0x8C,
	FLAG_SONIC_SS_LIGHTSHOOSE = 0x8D,
	FLAG_SONIC_SS_CRYSTALRING = 0x8E,
	FLAG_SONIC_EC_MONORAIL = 0x8F,
	FLAG_SONIC_EC_EGGLIFT = 0x90,
	FLAG_SONIC_EC_TRANSFORM = 0x91,
	FLAG_SONIC_EC_TORNADO2_LOST = 0x92,
	FLAG_SONIC_EC_SINK = 0x93,
	FLAG_SONIC_MR_WINDYSTONE = 0x94,
	FLAG_SONIC_MR_ENTRANCE_WINDY = 0x95,
	FLAG_SONIC_MR_WESTROCK = 0x96,
	FLAG_SONIC_MR_ICESTONE = 0x97,
	FLAG_SONIC_MR_ENTRANCE_ICECAP = 0x98,
	FLAG_SONIC_MR_ENTRANCE_MOUNTAIN = 0x99,
	FLAG_SONIC_MR_ISLANDDOOR = 0x9A,
	FLAG_SONIC_MR_TRUCK = 0x9B,
	FLAG_SONIC_MR_ENTRANCE_RUIN = 0x9C,
	FLAG_SONIC_MR_APPEAR_FINALEGG = 0x9D,
	FLAG_SONIC_MR_ENTRANCE_SANDBOARD = 0x9E,
	FLAG_SONIC_MR_ANCIENT_LIGHT = 0x9F,
	FLAG_SONIC_MR_ENTRANCE_FINALEGG = 0xA0,
	FLAG_SONIC_TRAIN = 0xA1,
	FLAG_SONIC_BOAT = 0xA2,
	FLAG_SONIC_RAFT = 0xA3,
	FLAG_SONIC_MBOSS_E102 = 0xA4,
	FLAG_SONIC_MBOSS_KNUCKLES = 0xA5,
	FLAG_SONIC_CLEAR_BEACH = 0xA6,
	FLAG_SONIC_CLEAR_WINDY = 0xA7,
	FLAG_SONIC_CLEAR_CASINO = 0xA8,
	FLAG_SONIC_CLEAR_TWINKLEPARK = 0xA9,
	FLAG_SONIC_CLEAR_HIGHWAY = 0xAA,
	FLAG_SONIC_CLEAR_MOUNTAIN = 0xAB,
	FLAG_SONIC_CLEAR_SNOW = 0xAC,
	FLAG_SONIC_CLEAR_SKYDECK = 0xAD,
	FLAG_SONIC_CLEAR_RUIN = 0xAE,
	FLAG_SONIC_CLEAR_FINALEGG = 0xAF,
	FLAG_SONIC_CLEAR_CHAOS0 = 0xB0,
	FLAG_SONIC_CLEAR_CHAOS4 = 0xB1,
	FLAG_SONIC_CLEAR_CHAOS6 = 0xB2,
	FLAG_SONIC_CLEAR_EGGMOBILE1 = 0xB3,
	FLAG_SONIC_CLEAR_EGGMOBILE3 = 0xB4,
	FLAG_SONIC_CLEAR_SHOOTING = 0xB5,
	FLAG_SONIC_CLEAR_SHOOTING2 = 0xB6,
	FLAG_SONIC_ARRIVE_IN_SS = 0xB7,
	FLAG_SONIC_ARRIVE_IN_EC = 0xB8,
	FLAG_SONIC_ARRIVE_IN_MR = 0xB9,
	FLAG_MILES_SS_BARRICADE = 0xC0,
	FLAG_MILES_SS_HOTEL_FRONT = 0xC1,
	FLAG_MILES_SS_HOTEL_BACK = 0xC2,
	FLAG_MILES_SS_HOTEL_POOL = 0xC3,
	FLAG_MILES_SS_ICESTONE = 0xC4,
	FLAG_MILES_SS_ENTRANCE_CASINO = 0xC5,
	FLAG_MILES_SS_ENTRANCE_HIGHWAY = 0xC6,
	FLAG_MILES_SS_TPARK_ELEVATOR = 0xC7,
	FLAG_MILES_SS_ENTRANCE_CIRCUIT = 0xC8,
	FLAG_MILES_SS_CARTPASSPORT = 0xC9,
	FLAG_MILES_SS_STATION_FRONT = 0xCA,
	FLAG_MILES_SS_STATION_BACK = 0xCB,
	FLAG_MILES_SS_HOTELSWITCH = 0xCC,
	FLAG_MILES_SS_JETANKLET = 0xCD,
	FLAG_MILES_EC_MONORAIL = 0xCE,
	FLAG_MILES_EC_EGGLIFT = 0xCF,
	FLAG_MILES_EC_TRANSFORM = 0xD0,
	FLAG_MILES_EC_TORNADO2_LOST = 0xD1,
	FLAG_MILES_EC_SINK = 0xD2,
	FLAG_MILES_MR_WINDYSTONE = 0xD3,
	FLAG_MILES_MR_ENTRANCE_WINDY = 0xD4,
	FLAG_MILES_MR_WESTROCK = 0xD5,
	FLAG_MILES_MR_ICESTONE = 0xD6,
	FLAG_MILES_MR_ENTRANCE_ICECAP = 0xD7,
	FLAG_MILES_MR_TRUCK = 0xD8,
	FLAG_MILES_MR_ENTRANCE_RUIN = 0xD9,
	FLAG_MILES_MR_ENTRANCE_SANDBOARD = 0xDA,
	FLAG_MILES_MR_RHYTHMBROOCH = 0xDB,
	FLAG_MILES_TRAIN = 0xDC,
	FLAG_MILES_BOAT = 0xDD,
	FLAG_MILES_RAFT = 0xDE,
	FLAG_MILES_MBOSS_E102 = 0xDF,
	FLAG_MILES_MBOSS_KNUCKLES = 0xE0,
	FLAG_MILES_CLEAR_WINDY = 0xE1,
	FLAG_MILES_CLEAR_CASINO = 0xE2,
	FLAG_MILES_CLEAR_HIGHWAY = 0xE3,
	FLAG_MILES_CLEAR_SNOW = 0xE4,
	FLAG_MILES_CLEAR_SKYDECK = 0xE5,
	FLAG_MILES_CLEAR_SANDBOARD = 0xE6,
	FLAG_MILES_CLEAR_CHAOS4 = 0xE7,
	FLAG_MILES_CLEAR_EGGMOBILE2 = 0xE8,
	FLAG_MILES_CLEAR_EGGMOBILE1 = 0xE9,
	FLAG_MILES_CLEAR_SHOOTING = 0xEA,
	FLAG_MILES_CLEAR_SHOOTING2 = 0xEB,
	FLAG_MILES_CLEAR_BEACH = 0xEC,
	FLAG_MILES_CLEAR_MOUNTAIN = 0xED,
	FLAG_MILES_ARRIVE_IN_SS = 0xEE,
	FLAG_MILES_ARRIVE_IN_EC = 0xEF,
	FLAG_MILES_ARRIVE_IN_MR = 0xF0,
	FLAG_KNUCKLES_SS_BARRICADE = 0x100,
	FLAG_KNUCKLES_SS_HOTEL_FRONT = 0x101,
	FLAG_KNUCKLES_SS_HOTEL_BACK = 0x102,
	FLAG_KNUCKLES_SS_ENTRANCE_CASINO = 0x103,
	FLAG_KNUCKLES_SS_ENTRANCE_HIGHWAY = 0x104,
	FLAG_KNUCKLES_SS_TPARK_ELEVATOR = 0x105,
	FLAG_KNUCKLES_SS_ENTRANCE_CIRCUIT = 0x106,
	FLAG_KNUCKLES_SS_CARTPASSPORT = 0x107,
	FLAG_KNUCKLES_SS_STATION_FRONT = 0x108,
	FLAG_KNUCKLES_SS_STATION_BACK = 0x109,
	FLAG_KNUCKLES_EC_MONORAIL = 0x10A,
	FLAG_KNUCKLES_EC_EGGLIFT = 0x10B,
	FLAG_KNUCKLES_EC_TRANSFORM = 0x10C,
	FLAG_KNUCKLES_EC_PALMSWITCH = 0x10D,
	FLAG_KNUCKLES_EC_TORNADO2_LOST = 0x10E,
	FLAG_KNUCKLES_EC_SINK = 0x10F,
	FLAG_KNUCKLES_MR_ENTRANCE_MOUNTAIN = 0x110,
	FLAG_KNUCKLES_MR_WESTROCK = 0x111,
	FLAG_KNUCKLES_MR_ISLANDDOOR = 0x112,
	FLAG_KNUCKLES_MR_MONKEYDOOR = 0x113,
	FLAG_KNUCKLES_MR_TRUCK = 0x114,
	FLAG_KNUCKLES_MR_REDCUBE = 0x115,
	FLAG_KNUCKLES_MR_BLUECUBE = 0x116,
	FLAG_KNUCKLES_MR_ENTRANCE_RUIN = 0x117,
	FLAG_KNUCKLES_MR_APPEAR_FINALEGG = 0x118,
	FLAG_KNUCKLES_MR_SHOVELCLAW = 0x119,
	FLAG_KNUCKLES_MR_FIGHTINGGROVE = 0x11A,
	FLAG_KNUCKLES_TRAIN = 0x11B,
	FLAG_KNUCKLES_BOAT = 0x11C,
	FLAG_KNUCKLES_RAFT = 0x11D,
	FLAG_KNUCKLES_MBOSS_SONIC = 0x11E,
	FLAG_KNUCKLES_CLEAR_CASINO = 0x11F,
	FLAG_KNUCKLES_CLEAR_HIGHWAY = 0x120,
	FLAG_KNUCKLES_CLEAR_MOUNTAIN = 0x121,
	FLAG_KNUCKLES_CLEAR_RUIN = 0x122,
	FLAG_KNUCKLES_CLEAR_CHAOS2 = 0x123,
	FLAG_KNUCKLES_CLEAR_CHAOS6 = 0x124,
	FLAG_KNUCKLES_CLEAR_CHAOS4 = 0x125,
	FLAG_KNUCKLES_CLEAR_SKYDECK = 0x126,
	FLAG_KNUCKLES_ARRIVE_IN_SS = 0x127,
	FLAG_KNUCKLES_ARRIVE_IN_EC = 0x128,
	FLAG_KNUCKLES_ARRIVE_IN_MR = 0x129,
	FLAG_KNUCKLES_MR_MONKEYDOOR_ENTER = 0x12A,
	FLAG_KNUCKLES_MR_MONKEYCAGEA_BOMB = 0x12B,
	FLAG_KNUCKLES_SS_ENTRANCE_CHAOS2 = 0x12C,
	FLAG_AMY_SS_HOTEL_FRONT = 0x140,
	FLAG_AMY_SS_HOTEL_BACK = 0x141,
	FLAG_AMY_SS_HOTEL_POOL = 0x142,
	FLAG_AMY_SS_ENTRANCE_CASINO = 0x143,
	FLAG_AMY_SS_TPARK_ELEVATOR = 0x144,
	FLAG_AMY_SS_ENTRANCE_CIRCUIT = 0x145,
	FLAG_AMY_SS_STATION_FRONT = 0x146,
	FLAG_AMY_SS_STATION_BACK = 0x147,
	FLAG_AMY_EC_MONORAIL = 0x148,
	FLAG_AMY_EC_EGGLIFT = 0x149,
	FLAG_AMY_EC_TRANSFORM = 0x14A,
	FLAG_AMY_EC_MOGURATATAKI = 0x14B,
	FLAG_AMY_EC_TORNADO2_LOST = 0x14C,
	FLAG_AMY_EC_SINK = 0x14D,
	FLAG_AMY_MR_ISLANDDOOR = 0x14E,
	FLAG_AMY_MR_TRUCK = 0x14F,
	FLAG_AMY_MR_APPEAR_FINALEGG = 0x150,
	FLAG_AMY_MR_ENTRANCE_FINALEGG = 0x151,
	FLAG_AMY_MR_FIGHTERSFEATHER = 0x152,
	FLAG_AMY_TRAIN = 0x153,
	FLAG_AMY_BOAT = 0x154,
	FLAG_AMY_RAFT = 0x155,
	FLAG_AMY_CLEAR_TWINKLEPARK = 0x156,
	FLAG_AMY_CLEAR_HOTSHELTER = 0x157,
	FLAG_AMY_CLEAR_FINALEGG = 0x158,
	FLAG_AMY_CLEAR_ZERO = 0x159,
	FLAG_AMY_EC_1STVISIT = 0x15A,
	FLAG_AMY_ARRIVE_IN_SS = 0x15B,
	FLAG_AMY_ARRIVE_IN_EC = 0x15C,
	FLAG_AMY_ARRIVE_IN_MR = 0x15D,
	FLAG_AMY_EC_LONGHAMMER = 0x15E,
	FLAG_E102_SS_HOTEL_FRONT = 0x180,
	FLAG_E102_SS_HOTEL_POOL = 0x181,
	FLAG_E102_SS_STATION_FRONT = 0x182,
	FLAG_E102_SS_TPARK_ELEVATOR = 0x183,
	FLAG_E102_SS_ENTRANCE_CIRCUIT = 0x184,
	FLAG_E102_SS_CARTPASSPORT = 0x185,
	FLAG_E102_EC_MONORAIL = 0x186,
	FLAG_E102_EC_EGGLIFT = 0x187,
	FLAG_E102_EC_TRANSFORM = 0x188,
	FLAG_E102_EC_BOOSTER = 0x189,
	FLAG_E102_EC_TYPE3LASER = 0x18A,
	FLAG_E102_EC_TORNADO2_LOST = 0x18B,
	FLAG_E102_EC_SINK = 0x18C,
	FLAG_E102_EC_HOTSHELTER = 0x18D,
	FLAG_E102_MR_GOODSCORE = 0x18E,
	FLAG_E102_MR_FREEPASS = 0x18F,
	FLAG_E102_MR_WINDYSTONE = 0x190,
	FLAG_E102_MR_ENTRANCE_WINDY = 0x191,
	FLAG_E102_MR_WESTROCK = 0x192,
	FLAG_E102_MR_ENTRANCE_MOUNTAIN = 0x193,
	FLAG_E102_MR_ISLANDDOOR = 0x194,
	FLAG_E102_MR_TRUCK = 0x195,
	FLAG_E102_MR_APPEAR_FINALEGG = 0x196,
	FLAG_E102_TRAIN = 0x197,
	FLAG_E102_BOAT = 0x198,
	FLAG_E102_RAFT = 0x199,
	FLAG_E102_MBOSS_SONIC = 0x19A,
	FLAG_E102_CLEAR_BEACH = 0x19B,
	FLAG_E102_CLEAR_WINDY = 0x19C,
	FLAG_E102_CLEAR_MOUNTAIN = 0x19D,
	FLAG_E102_CLEAR_HOTSHELTER = 0x19E,
	FLAG_E102_CLEAR_FINALEGG = 0x19F,
	FLAG_E102_CLEAR_E101 = 0x1A0,
	FLAG_E102_CLEAR_E101R = 0x1A1,
	FLAG_E102_ARRIVE_IN_SS = 0x1A2,
	FLAG_E102_ARRIVE_IN_EC = 0x1A3,
	FLAG_E102_ARRIVE_IN_MR = 0x1A4,
	FLAG_BIG_SS_HOTEL_FRONT = 0x1C0,
	FLAG_BIG_SS_HOTEL_BACK = 0x1C1,
	FLAG_BIG_SS_TPARK_ELEVATOR = 0x1C2,
	FLAG_BIG_SS_ENTRANCE_CIRCUIT = 0x1C3,
	FLAG_BIG_SS_STATION_FRONT = 0x1C4,
	FLAG_BIG_SS_ICESTONE = 0x1C5,
	FLAG_BIG_SS_HOTEL_POOL = 0x1C6,
	FLAG_BIG_EC_MONORAIL = 0x1C7,
	FLAG_BIG_EC_EGGLIFT = 0x1C8,
	FLAG_BIG_EC_TRANSFORM = 0x1C9,
	FLAG_BIG_EC_TORNADO2_LOST = 0x1CA,
	FLAG_BIG_EC_SINK = 0x1CB,
	FLAG_BIG_MR_WESTROCK = 0x1CC,
	FLAG_BIG_MR_ICESTONE = 0x1CD,
	FLAG_BIG_MR_ENTRANCE_ICECAP = 0x1CE,
	FLAG_BIG_MR_TRUCK = 0x1CF,
	FLAG_BIG_MR_LIFEBELT = 0x1D0,
	FLAG_BIG_MR_POWERROD = 0x1D1,
	FLAG_BIG_TRAIN = 0x1D2,
	FLAG_BIG_BOAT = 0x1D3,
	FLAG_BIG_RAFT = 0x1D4,
	FLAG_BIG_CLEAR_BEACH = 0x1D5,
	FLAG_BIG_CLEAR_HOTSHELTER = 0x1D6,
	FLAG_BIG_CLEAR_TWINKLEPARK = 0x1D7,
	FLAG_BIG_CLEAR_SNOW = 0x1D8,
	FLAG_BIG_CLEAR_CHAOS6 = 0x1D9,
	FLAG_BIG_ARRIVE_IN_SS = 0x1DA,
	FLAG_BIG_ARRIVE_IN_EC = 0x1DB,
	FLAG_BIG_ARRIVE_IN_MR = 0x1DC,
	FLAG_BIG_ARRIVE_IN_SEWER = 0x1DD,
	FLAG_BIG_RUAR_BLUE = 0x1DE,
	FLAG_BIG_RUAR_GOLD = 0x1DF,
	FLAG_BIG_RUAR_NORMAL = 0x1E0,
	FLAG_BIG_RUAR_RED = 0x1E1,
	FLAG_BIG_RUAR_SILVER = 0x1E2,
	FLAG_EVENT_HINTBOX_DISP = 0x1E3,
	FLAG_EVENT_NPC_DISP = 0x1E4,
	FLAG_ALL_LAST = 0x1E5,
};

enum EV
{
	EV_INIT = 0x0,
	EV_MAIN = 0x1,
	EV_CANSEL = 0x2,
	EV_CLOSE = 0x3,
	EV_END = 0x4,
};

enum mlt
{
	emeraldcoast_mlt = 0x0,
	p_sonictails_mlt = 0x1,
	alife_mlt = 0x2,
	alife_amy_mlt = 0x3,
	alife_amy_e_mlt = 0x4,
	alife_big_mlt = 0x5,
	alife_big_e_mlt = 0x6,
	alife_e102_mlt = 0x7,
	alife_e102_e_mlt = 0x8,
	alife_knuckles_mlt = 0x9,
	alife_knuckles_e_mlt = 0xA,
	alife_sonic_mlt = 0xB,
	alife_sonic_e_mlt = 0xC,
	alife_tails_mlt = 0xD,
	alife_tails_e_mlt = 0xE,
	alt_e102_mlt = 0xF,
	alt_e102_e_mlt = 0x10,
	alt_eggcarrier_mlt = 0x11,
	alt_knuckles_mlt = 0x12,
	alt_knuckles_e_mlt = 0x13,
	alt_mysticruin_mlt = 0x14,
	alt_sonictails_mlt = 0x15,
	alt_sonictails_e_mlt = 0x16,
	cart_mlt = 0x17,
	casinopolis_mlt = 0x18,
	casino_knuckles_mlt = 0x19,
	casino_sonictails_mlt = 0x1A,
	chaos0_mlt = 0x1B,
	chaos2_mlt = 0x1C,
	chaos4_mlt = 0x1D,
	chaos6_mlt = 0x1E,
	chaos7a_mlt = 0x1F,
	chaos7b_mlt = 0x20,
	drymountain_mlt = 0x21,
	e101_mlt = 0x22,
	e101r_mlt = 0x23,
	eggcarrier_mlt = 0x24,
	finalegg_mlt = 0x25,
	highway_mlt = 0x26,
	hotshelter_mlt = 0x27,
	icecap_mlt = 0x28,
	lostworld_mlt = 0x29,
	mobile1_mlt = 0x2A,
	mobile2_mlt = 0x2B,
	mobile3_mlt = 0x2C,
	mysticruin_mlt = 0x2D,
	p_amy_mlt = 0x2E,
	p_big_mlt = 0x2F,
	p_e102_mlt = 0x30,
	p_knuckles_mlt = 0x31,
	sandhill_mlt = 0x32,
	shooting_mlt = 0x33,
	skydeck_mlt = 0x34,
	skydeck_e_mlt = 0x35,
	stationsquare_mlt = 0x36,
	twinklepark_mlt = 0x37,
	windyvalley_mlt = 0x38,
	casino_knucklesvoice_mlt = 0x39,
	casino_knucklesvoice_e_mlt = 0x3A,
	casino_sonictailsvoice_mlt = 0x3B,
	casino_sonictailsvoice_e_mlt = 0x3C,
	chao_efx_mlt = 0x3D,
	p_metaltails_mlt = 0x3E,
	v_amy_mlt = 0x3F,
	v_amy_e_mlt = 0x40,
	v_big_mlt = 0x41,
	v_big_e_mlt = 0x42,
	v_e102_mlt = 0x43,
	v_e102_e_mlt = 0x44,
	v_knuckles_mlt = 0x45,
	v_knuckles_e_mlt = 0x46,
	v_sonictails_mlt = 0x47,
	v_sonictails_e_mlt = 0x48,
	e_0001_mlt = 0x49,
	e_0003_mlt = 0x4A,
	e_0007_mlt = 0x4B,
	e_0008_mlt = 0x4C,
	e_0009_mlt = 0x4D,
	e_000d_mlt = 0x4E,
	e_0012_mlt = 0x4F,
	e_0016_mlt = 0x50,
	e_001b_mlt = 0x51,
	e_001e_mlt = 0x52,
	e_0022_mlt = 0x53,
	e_0024_mlt = 0x54,
	e_0029_mlt = 0x55,
	e_0035_mlt = 0x56,
	e_0042_mlt = 0x57,
	e_0046_mlt = 0x58,
	e_0047_mlt = 0x59,
	e_004b_mlt = 0x5A,
	e_004d_mlt = 0x5B,
	e_004e_mlt = 0x5C,
	e_0060_mlt = 0x5D,
	e_0061_mlt = 0x5E,
	e_0064_mlt = 0x5F,
	e_0065_mlt = 0x60,
	e_0068_mlt = 0x61,
	e_0071_mlt = 0x62,
	e_0080_mlt = 0x63,
	e_0087_mlt = 0x64,
	e_0091_mlt = 0x65,
	e_0097_mlt = 0x66,
	e_009d_mlt = 0x67,
	e_00b0_mlt = 0x68,
	e_00b7_mlt = 0x69,
	e_00ba_mlt = 0x6A,
	e_00bb_mlt = 0x6B,
	e_00bf_mlt = 0x6C,
	e_00c5_mlt = 0x6D,
	e_00d0_mlt = 0x6E,
	e_00d4_mlt = 0x6F,
	e_00de_mlt = 0x70,
	e_00f3_mlt = 0x71,
	e_00f4_mlt = 0x72,
	e_00f5_mlt = 0x73,
	e_00f7_mlt = 0x74,
	e_00f8_mlt = 0x75,
	e_00fa_mlt = 0x76,
	e_00fd_mlt = 0x77,
	e_00fe_mlt = 0x78,
	e_00ff_mlt = 0x79,
	e_0160_mlt = 0x7A,
	mltdata_max = 0x7B,
};

enum CHSEL_MODE
{
	CHSEL_MODE_ADVENTURE = 0x0,
	CHSEL_MODE_TRIAL = 0x1,
	CHSEL_MODE_MISSION = 0x2,
};

enum MD_GameMode
{
	MD_START = 0x0,
	MD_LOGO = 0x1,
	MD_TITLE = 0x2,
	MD_SELECTPLAYER = 0x3,
	MD_ACTION = 0x4,
	MD_ADVENTURE = 0x5,
	MD_CONTINUE = 0x6,
	MD_END = 0x7,
	MD_MOVIE = 0x8,
	MD_TRIAL = 0x9,
	MD_MISSION = 0xA,
	MD_TITLE2_INIT = 0xB,
	MD_TITLE2 = 0xC,
	MD_NOVMSWND_INIT = 0xD,
	MD_NOVMSWND = 0xE,
	MD_CHARA_SELECT_INIT = 0xF,
	MD_CHARA_SELECT = 0x10,
	MD_SUMMARY_INIT = 0x11,
	MD_SUMMARY = 0x12,
	MD_TUTORIAL_INIT = 0x13,
	MD_TUTORIAL = 0x14,
	MD_STAFFROLL_INIT = 0x15,
	MD_STAFFROLL = 0x16,
	MD_TVSETTING_END = 0x17,
	MD_LOGO_INIT = 0x18,
	NUM_MODE = 0x19,
};

enum CID
{
	CID_PLAYER = 0x0,
	CID_BULLET = 0x1,
	CID_ENEMY = 0x2,
	CID_ENEMY2 = 0x3,
	CID_OBJECT = 0x4,
	CID_OBJECT2 = 0x5,
	CID_ITEM = 0x6,
	CID_ITEM2 = 0x7,
	CID_WALL = 0x8,
	CID_CHAO = 0x9,
};

enum PL_OP
{
	PL_OP_NONE = 0x0,
	PL_OP_1DRUN = 0x1,
	PL_OP_1DSPIN = 0x2,
	PL_OP_SPRING = 0x3,
	PL_OP_CANON = 0x4,
	PL_OP_PARABOLIC = 0x5,
	PL_OP_TRAMPOLINEJUMP1 = 0x6,
	PL_OP_TRAMPOLINEJUMP2 = 0x7,
	PL_OP_TRAMPOLINEJUMP3 = 0x8,
	PL_OP_TRAMPOLINERIDE2 = 0x9,
	PL_OP_TRAMPOLINERIDE3 = 0xA,
	PL_OP_ASCEND = 0xB,
	PL_OP_PLACEON = 0xC,
	PL_OP_PLACEWITHSPIN = 0xD,
	PL_OP_PLACEWITHRUN = 0xE,
	PL_OP_PLACEWITHPUSH = 0xF,
	PL_OP_PLACEWITHHUNG = 0x10,
	PL_OP_PLACEWITHFALL = 0x11,
	PL_OP_PLACEWITHCART = 0x12,
	PL_OP_PLACEWITHKIME = 0x13,
	PL_OP_PLACEWITHROCKET = 0x14,
	PL_OP_PLACEWITHROCKETH = 0x15,
	PL_OP_PLACEWITHROCKETV = 0x16,
	PL_OP_PLACEWITHRAFT = 0x17,
	PL_OP_LETITGO = 0x18,
	PL_OP_SPINDASH = 0x19,
	PL_OP_SEEPATH = 0x1A,
	PL_OP_EVENTMOTION = 0x1B,
	PL_OP_GETOUTOFCART = 0x1C,
	PL_OP_HANGDOWNFROMPATH = 0x1D,
	PL_OP_HOLDONICICLE = 0x1E,
	PL_OP_LADDERINGPATH = 0x1F,
	PL_OP_HOLDONPILLAR = 0x20,
	PL_OP_CAPTURED = 0x21,
	PL_OP_LOOKAROUND = 0x22,
	PL_OP_CRASH = 0x23,
	PL_OP_BREATH = 0x24,
	PL_OP_HOLDTASK = 0x25,
	PL_OP_ICED = 0x26,
	PL_OP_DOZAEMON = 0x27,
	PL_OP_STARTSHOWER = 0x28,
	PL_OP_STOPSHOWER = 0x29,
	PL_OP_SHAKEMUDOUT = 0x2A,
	PL_OP_BUILDING = 0x2B,
	PL_OP_SNOWBOARDING = 0x2C,
	PL_OP_PINBALL = 0x2D,
	PL_OP_SUPER = 0x2E,
	PL_OP_NORMAL = 0x2F,
	PL_OP_FLY = 0x30,
	PL_OP_PROP = 0x31,
	PL_OP_KILLED = 0x32,
};

enum SEQ_TIME
{
	SEQ_DAYLIGHT = 0x0,
	SEQ_EVENING = 0x1,
	SEQ_NIGHT = 0x2,
	SEQ_TIME_MAX = 0x3,
};

enum CI_FORM
{
	CI_FORM_SPHERE = 0x0,
	CI_FORM_CYLINDER = 0x1,
	CI_FORM_CYLINDER2 = 0x2,
	CI_FORM_RECTANGLE = 0x3,
	CI_FORM_RECTANGLE2 = 0x4,
	CI_FORM_RECTANGLE3 = 0x5,
	CI_FORM_CAPSULE = 0x6,
	CI_FORM_PERSON = 0x7,
	CI_FORM_LINE = 0x8,
	CI_FORM_WALL_PLANE = 0x9,
	CI_FORM_WALL_CIRCLE = 0xA,
};

enum HINT_DATA
{
	HINT_DATA_START = 0xFFFFFFF8,
	HINT_FLAG_CHECK = 0xFFFFFFF9,
	HINT_EVENT_CHECK = 0xFFFFFFFA,
	HINT_PLAYER_CHECK = 0xFFFFFFFB,
	HINT_ADX_INDEX = 0xFFFFFFFC,
	HINT_SET_FLAG = 0xFFFFFFFD,
	HINT_DATA_SEGMENT = 0xFFFFFFFE,
	HINT_DATA_END = 0xFFFFFFFF,
};

enum EnumSSPAct
{
	ENUM_ACT_OFFICE = 0x0,
	ENUM_ACT_CASINO = 0x1,
	ENUM_ACT_GESUI = 0x2,
	ENUM_ACT_STATION = 0x3,
	ENUM_ACT_HOTEL = 0x4,
	ENUM_ACT_TWINKLE = 0x5,
	ENUM_ACT_END = 0x6,
};

enum EnumSSPcIndex
{
	ENUM_SSPC_SONIC = 0x0,
	ENUM_SSPC_MILES = 0x1,
	ENUM_SSPC_KNUCKLES = 0x2,
	ENUM_SSPC_AMY = 0x3,
	ENUM_SSPC_E102 = 0x4,
	ENUM_SSPC_BIG = 0x5,
	ENUM_SSPC_KAERU = 0x6,
	ENUM_SSPC_SONIC2 = 0x7,
	ENUM_SSPC_MILES2 = 0x8,
	ENUM_SSPC_EGGMAN = 0x9,
	ENUM_SSPC_MAX = 0xA,
};

enum PORTABLE
{
	PORTABLE_NOTHING = 0x0,
	PORTABLE_ICESTONE = 0x1,
	PORTABLE_WINDSTONE = 0x2,
	PORTABLE_CARD = 0x3,
	PORTABLE_CARTPASSPORT = 0x4,
	PORTABLE_EGG_SS = 0x5,
	PORTABLE_EGG_SS_FAKE = 0x6,
	PORTABLE_REDCUBE = 0x7,
	PORTABLE_BLUECUBE = 0x8,
	PORTABLE_KILLMONKY = 0x9,
	PORTABLE_EGG_MR = 0xA,
	PORTABLE_EGG_EC = 0xB,
	PORTABLE_SS_MANNEQUIN = 0xC,
	PORTABLE_NUM = 0xD,
};

enum CAMADJ
{
	CAMADJ_NONE = 0x0,
	CAMADJ_NORMAL = 0x1,
	CAMADJ_NORMAL_S = 0x2,
	CAMADJ_SLOW = 0x3,
	CAMADJ_SLOW_S = 0x4,
	CAMADJ_TIME = 0x5,
	CAMADJ_THREE1 = 0x6,
	CAMADJ_THREE1C = 0x7,
	CAMADJ_THREE2 = 0x8,
	CAMADJ_THREE2C = 0x9,
	CAMADJ_THREE3 = 0xA,
	CAMADJ_THREE3C = 0xB,
	CAMADJ_THREE4 = 0xC,
	CAMADJ_THREE4C = 0xD,
	CAMADJ_THREE5 = 0xE,
	CAMADJ_THREE5C = 0xF,
	CAMADJ_RELATIVE1 = 0x10,
	CAMADJ_RELATIVE1C = 0x11,
	CAMADJ_RELATIVE2 = 0x12,
	CAMADJ_RELATIVE2C = 0x13,
	CAMADJ_RELATIVE3 = 0x14,
	CAMADJ_RELATIVE3C = 0x15,
	CAMADJ_RELATIVE4 = 0x16,
	CAMADJ_RELATIVE4C = 0x17,
	CAMADJ_RELATIVE5 = 0x18,
	CAMADJ_RELATIVE5C = 0x19,
	CAMADJ_RELATIVE6C = 0x1A,
	CAMADJ_FORFREECAMERA = 0x1B,
	CAMADJ_NUM = 0x1C,
};

enum eCreamEventIndex
{
	CREAM_EVENT_SONIC_ICESTONE = 0x0,
	CREAM_EVENT_TAILS_ICESTONE = 0x1,
	CREAM_EVENT_KNUCKLES_CASINO = 0x2,
	CREAM_EVENT_AMY_MEET_ZERO = 0x3,
	CREAM_EVENT_E_102_FIRST_SORTIE = 0x4,
	CREAM_EVENT_BIG_ICESTONE = 0x5,
	NUM_CREAM_EVENT_IDX = 0x6,
};

enum MOVE_MODE
{
	MOVE_MODE_NORMAL = 0x0,
	MOVE_MODE_STOP = 0x1,
	MOVE_MODE_POINT = 0x2,
	MOVE_MODE_SPEED = 0x3,
	MOVE_MODE_ACCEL = 0x4,
	MOVE_MODE_ROTATION = 0x5,
	MOVE_MODE_ANGLE = 0x6,
};

enum CREAM_MODE
{
	CREAM_INIT = 0x0,
	CREAM_MOVE = 0x1,
	CREAM_END = 0x2,
};

enum CREAM_MANAGER
{
	INIT_CREAM_MANAGER = 0x0,
	COLL_CREAM_MANAGER = 0x1,
	EVENT_CAM_CREAM_MANAGER = 0x2,
	WAIT_CREAM_MANAGER = 0x3,
};

enum LIGHT_
{
	LIGHT_OUTDOOR = 0x0,
	LIGHT_INDOOR = 0x1,
	LIGHT_END = 0x2,
};

enum sspmotion_type
{
	ENUM_SSPMOTION_START = 0x0,
	ENUM_SSPMOTION_WAIT_START = 0x0,
	ENUM_SSPMOTION_WAIT1 = 0x0,
	ENUM_SSPMOTION_WAIT2 = 0x1,
	ENUM_SSPMOTION_WAIT3 = 0x2,
	ENUM_SSPMOTION_WAIT_END = 0x2,
	ENUM_SSPMOTION_TALK_START = 0x3,
	ENUM_SSPMOTION_TALK1 = 0x3,
	ENUM_SSPMOTION_TALK2 = 0x4,
	ENUM_SSPMOTION_TALK_END = 0x4,
	ENUM_SSPMOTION_WALK = 0x5,
	ENUM_SSPMOTION_DAMAGE = 0x6,
	ENUM_SSPMOTION_MAX = 0x7,
};

enum sspmodel_type
{
	ENUM_SSPMODEL_GENTLEMAN = 0x0,
	ENUM_SSPMODEL_OL = 0x1,
	ENUM_SSPMODEL_MIZUGI = 0x2,
	ENUM_SSPMODEL_GIRL = 0x3,
	ENUM_SSPMODEL_FATMAN = 0x4,
	ENUM_SSPMODEL_BOY = 0x5,
	ENUM_SSPMODEL_MAX = 0x6,
};

enum EGG_MODE
{
	EGG_OFF = 0x0,
	EGG_ON = 0x1,
	EGG_END = 0x2,
};

enum SSCAR
{
	CAR2 = 0x0,
	PATCAR = 0x1,
	TAXI = 0x2,
	ROTYU = 0x3,
	CAR_END = 0x4,
};

enum MODE_SSS2SAKU
{
	MODE_SSS2SAKU_INIT = 0x0,
	MODE_SSS2SAKU_UP = 0x1,
	MODE_SSS2SAKU_DOWN_L = 0x2,
	MODE_SSS2SAKU_DOWN_M = 0x3,
	MODE_SSS2SAKU_DOWN_U = 0x4,
	MODE_SSS2SAKU_DOWN = 0x5,
	MODE_SSS2SAKU_UP_L = 0x6,
	MODE_SSS2SAKU_UP_M = 0x7,
	MODE_SSS2SAKU_UP_U = 0x8,
	MODE_SSS2SAKU_END = 0x9,
};

enum MODE_SSSIGNAL
{
	MODE_SSSIGNAL_INIT = 0x0,
	MODE_SSSIGNAL_GREEN = 0x1,
	MODE_SSSIGNAL_YELLOW = 0x2,
	MODE_SSSIGNAL_RED = 0x3,
	MODE_SSSIGNAL_END = 0x4,
};

enum LANDANIM_SS
{
	LANDANIM_PLACE02GESUI = 0x0,
	LANDANIM_PLACE03SEA = 0x1,
	LANDANIM_PLACE03SAND = 0x2,
	LANDANIM_PLACE03WAVE = 0x3,
	LANDANIM_PLACE04SEA = 0x4,
	LANDANIM_PLACE04SAND = 0x5,
	LANDANIM_PLACE04WAVE = 0x6,
	LANDANIM_END = 0x7,
};

enum CAMMD
{
	CAMMD_FOLLOW = 0x0,
	CAMMD_A_FOLLOW = 0x1,
	CAMMD_C_FOLLOW = 0x2,
	CAMMD_COL_FOLLOW = 0x3,
	CAMMD_KNUCKLES = 0x4,
	CAMMD_A_KNUCKLES = 0x5,
	CAMMD_C_KNUCKLES = 0x6,
	CAMMD_COL_KNUCKLES = 0x7,
	CAMMD_KNUCKLES2 = 0x8,
	CAMMD_A_KNUCKLES2 = 0x9,
	CAMMD_C_KNUCKLES2 = 0xA,
	CAMMD_COL_KNUCKLES2 = 0xB,
	CAMMD_MAGONOTE = 0xC,
	CAMMD_A_MAGONOTE = 0xD,
	CAMMD_C_MAGONOTE = 0xE,
	CAMMD_COL_MAGONOTE = 0xF,
	CAMMD_SONIC = 0x10,
	CAMMD_A_SONIC = 0x11,
	CAMMD_C_SONIC = 0x12,
	CAMMD_COL_SONIC = 0x13,
	CAMMD_ASHLAND = 0x14,
	CAMMD_A_ASHLAND = 0x15,
	CAMMD_C_ASHLAND = 0x16,
	CAMMD_ASHLAND_I = 0x17,
	CAMMD_A_ASHLAND_I = 0x18,
	CAMMD_C_ASHLAND_I = 0x19,
	CAMMD_FISHING = 0x1A,
	CAMMD_A_FISHING = 0x1B,
	CAMMD_FIXED = 0x1C,
	CAMMD_A_FIXED = 0x1D,
	CAMMD_C_FIXED = 0x1E,
	CAMMD_KLAMATH = 0x1F,
	CAMMD_A_KLAMATH = 0x20,
	CAMMD_C_KLAMATH = 0x21,
	CAMMD_LINE = 0x22,
	CAMMD_A_LINE = 0x23,
	CAMMD_NEWFOLLOW = 0x24,
	CAMMD_A_NEWFOLLOW = 0x25,
	CAMMD_C_NEWFOLLOW = 0x26,
	CAMMD_POINT = 0x27,
	CAMMD_A_POINT = 0x28,
	CAMMD_C_POINT = 0x29,
	CAMMD_SONIC_P = 0x2A,
	CAMMD_A_SONIC_P = 0x2B,
	CAMMD_C_SONIC_P = 0x2C,
	CAMMD_ADVERTISE = 0x2D,
	CAMMD_BACK = 0x2E,
	CAMMD_BACK2 = 0x2F,
	CAMMD_BUILDING = 0x30,
	CAMMD_CART = 0x31,
	CAMMD_CHAOS = 0x32,
	CAMMD_CHAOS_P = 0x33,
	CAMMD_CHAOS_STINIT = 0x34,
	CAMMD_CHAOS_STD = 0x35,
	CAMMD_CHAOS_W = 0x36,
	CAMMD_E101R = 0x37,
	CAMMD_E103 = 0x38,
	CAMMD_EGM3 = 0x39,
	CAMMD_FOLLOW_G = 0x3A,
	CAMMD_A_FOLLOW_G = 0x3B,
	CAMMD_LR = 0x3C,
	CAMMD_COLLI = 0x3D,
	CAMMD_RuinWaka1 = 0x3E,
	CAMMD_SNOWBOARD = 0x3F,
	CAMMD_SURVEY = 0x40,
	CAMMD_TAIHO = 0x41,
	CAMMD_TORNADE = 0x42,
	CAMMD_TWO_HARES = 0x43,
	CAMMD_LEAVE = 0x44,
	CAMMD_AVOID = 0x45,
	CAMMD_A_AVOID = 0x46,
	CAMMD_C_AVOID = 0x47,
	CAMMD_COL_AVOID = 0x48,
	CAMMD_EDITOR = 0x49,
	CAMMD_GURIGURI = 0x4A,
	CAMMD_PATHCAM = 0x4B,
	CAMMD_KOSCAM = 0x4C,
	CAMMD_NUM = 0x4D,
};

enum GAMEMD
{
	GAMEMD_NOCHANGE = 0x0,
	GAMEMD_CLEAR = 0x1,
	GAMEMD_MISS = 0x2,
	GAMEMD_CHANGE = 0x3,
	GAMEMD_RESTART = 0x4,
	GAMEMD_RENEW = 0x5,
	GAMEMD_END = 0x6,
};

enum MOVIE
{
	MOVIE_LOGO_OPENING = 0x0,
	MOVIE_SS_DESTROY = 0x1,
	MOVIE_FALL_ISLAND = 0x2,
	MOVIE_RISE_ISLAND = 0x3,
	MOVIE_EC_2_SS = 0x4,
	MOVIE_EC_2_ISLAND = 0x5,
	MOVIE_EC_APPEAR = 0x6,
	MOVIE_EC_CRASH = 0x7,
	MOVIE_EC_DEPART = 0x8,
};

enum ITEM
{
	ITEM_HAYAASI = 0x0,
	ITEM_MUTEKI = 0x1,
	ITEM_5RING = 0x2,
	ITEM_10RING = 0x3,
	ITEM_RANDOMRING = 0x4,
	ITEM_BARIA = 0x5,
	ITEM_1UP = 0x6,
	ITEM_EKUSUPUROSYON = 0x7,
	ITEM_TH_BARIA = 0x8,
	ITEM_MAX = 0x9,
};

enum EnumECPcIndex
{
	ENUM_ECPC_SONIC = 0x0,
	ENUM_ECPC_MILES = 0x1,
	ENUM_ECPC_KNUCKLES = 0x2,
	ENUM_ECPC_AMY = 0x3,
	ENUM_ECPC_E102 = 0x4,
	ENUM_ECPC_BIG = 0x5,
	ENUM_ECPC_EGGMOBILE = 0x6,
	ENUM_ECPC_CHAOS4 = 0x7,
	ENUM_ECPC_MAX = 0x8,
};

enum EEcFlag
{
	eEcFlag_taiho2 = 0x0,
	eEcFlag_taiho5 = 0x1,
	eEcFlag_end = 0x2,
};

enum MD_PARASOL
{
	MD_PARASOL_INIT = 0x0,
	MD_PARASOL_NORMAL = 0x1,
	MD_PARASOL_EXIT = 0xFFFFFFFF,
};

enum MD_DOOR
{
	MD_DOOR_INIT = 0x0,
	MD_DOOR_NORMAL = 0x1,
	MD_DOOR_NORMAL2 = 0x2,
	MD_DOOR_OPEN = 0x3,
	MD_DOOR_CLOSE = 0x4,
	MD_DOOR_EXIT = 0xFFFFFFFF,
};

enum MONORAIL
{
	MONORAIL_NEITHER = 0x0,
	MONORAIL_FRONT = 0x1,
	MONORAIL_BACK = 0x2,
};

enum KN_IHD
{
	KN_IHD_FALSE = 0x0,
	KN_IHD_DIGD = 0x1,
	KN_IHD_DIGU = 0x2,
	KN_IHD_DIGT = 0x3,
	KN_IHD_PUNC = 0x4,
	KN_IHD_CLIM = 0x5,
	KN_IHD_CLIU = 0x6,
	KN_IHD_GLID = 0x7,
	KN_IHD_NMB = 0x8,
};

enum ECNPC
{
	NOT_PCNPC_START = 0xFFFFFFF6,
	CHAOS4 = 0xFFFFFFF6,
	EGG_CARRIER = 0xFFFFFFF7,
	NOT_PCNOC_END = 0xFFFFFFF8,
};

enum ANA
{
	ANA_INIT = 0x0,
	ANA_NONE = 0x1,
	ANA_UP = 0x2,
	ANA_WAIT = 0x3,
	ANA_DOWN = 0x4,
	ANA_BURST = 0x5,
	ANA_DOWN2 = 0x6,
	ANA_MAX = 0x7,
};

enum SEQID
{
	SEQ_SONIC_VS_KNUCKLES = 0x0,
	SEQ_SONIC_VS_E102 = 0x1,
	SEQ_MILES_VS_KNUCKLES = 0x2,
	SEQ_MILES_VS_E102 = 0x3,
	SEQ_KNUCKLES_VS_SONIC = 0x4,
	SEQ_E102_VS_SONIC = 0x5,
	SEQ_VS_NUM = 0x6,
};

enum EnumMRPcIndex
{
	ENUM_MRPC_SONIC = 0x0,
	ENUM_MRPC_MILES = 0x1,
	ENUM_MRPC_KNUCKLES = 0x2,
	ENUM_MRPC_BIG = 0x3,
	ENUM_MRPC_EGGMAN = 0x4,
	ENUM_MRPC_KNUCKLES2 = 0x5,
	ENUM_MRPC_EGGMAN2 = 0x6,
	ENUM_MRPC_EMERALD = 0x7,
	ENUM_MRPC_MAX = 0x8,
};

enum LOCK
{
	LOCK_ICE = 0x0,
	LOCK_WIND = 0x1,
	LOCK_GOLD = 0x2,
	LOCK_SILVER = 0x3,
};

enum MD_GAME
{
	MD_GAME_INIT = 0x0,
	MD_GAME_INIT2 = 0x1,
	MD_GAME_REINIT = 0x2,
	MD_GAME_REINIT2 = 0x3,
	MD_GAME_FADEIN = 0x4,
	MD_GAME_FADEOUT_CLEAR = 0x5,
	MD_GAME_FADEOUT_MISS = 0x6,
	MD_GAME_FADEOUT_MISS_RESTART = 0x7,
	MD_GAME_FADEOUT_OVER = 0x8,
	MD_GAME_FADEOUT_CHANGE = 0x9,
	MD_GAME_FADEOUT_CHANGE2 = 0xA,
	MD_GAME_FADEOUT_RESTART = 0xB,
	MD_GAME_FADEOUT_RENEW = 0xC,
	MD_GAME_FADEOUT_TITLE = 0xD,
	MD_GAME_FADEOUT_STAFFROLL = 0xE,
	MD_GAME_MAIN = 0xF,
	MD_GAME_PAUSE = 0x10,
	MD_GAME_END = 0x11,
	MD_GAME_OVER = 0x12,
	MD_GAME_CONTINUE = 0x13,
	MD_GAME_ABORT = 0x14,
	MD_GAME_STAGENAME_INIT = 0x15,
	MD_GAME_STAGENAME = 0x16,
	MD_GAME_TRIAL_OVER = 0x17,
	MD_GAME_END2 = 0x18,
	MD_GAME_MAIN_KEY_RELEASE_WAIT = 0x19,
	NUM_GAMEMD = 0x1A,
};

enum EnumPASTPcIndex
{
	ENUM_PASTPC_PACHACAMAC = 0x0,
	ENUM_PASTPC_CHAO1 = 0x1,
	ENUM_PASTPC_CHAO2 = 0x2,
	ENUM_PASTPC_CHAO3 = 0x3,
	ENUM_PASTPC_TIKAL = 0x4,
	ENUM_PASTPC_TIKAL2 = 0x5,
	ENUM_PASTPC_KNUCKLE1 = 0x6,
	ENUM_PASTPC_KNUCKLE2 = 0x7,
	ENUM_PASTPC_KNUCKLE3 = 0x8,
	ENUM_PASTPC_MAX = 0x9,
};

enum PASTPC
{
	PASTPC_CHAO = 0xFFFFFFFE,
	PASTPC_NOTPC = 0xFFFFFFFF,
	PASTPC_PC = 0x0,
};

enum pastp_index_check
{
	ENUM_PASTP_INDEX_UNDER_0 = 0xFFFFFFFF,
	ENUM_PASTP_INDEX_OVER_MAX = 0xFFFFFFFE,
};

enum pastpmodel_type
{
	ENUM_PASTPMODEL_NORMAL = 0x0,
	ENUM_PASTPMODEL_FAT = 0x1,
	ENUM_PASTPMODEL_TALL = 0x2,
	ENUM_PASTPMODEL_MAX = 0x3,
};

enum pastpmotion_type
{
	ENUM_PASTPMOTION_START = 0x0,
	ENUM_PASTPMOTION_WAIT_START = 0x0,
	ENUM_PASTPMOTION_WAIT_END = 0x0,
	ENUM_PASTPMOTION_TALK_START = 0x1,
	ENUM_PASTPMOTION_TALK1 = 0x1,
	ENUM_PASTPMOTION_TALK_END = 0x1,
	ENUM_PASTPMOTION_WALK = 0x2,
	ENUM_PASTPMOTION_DAMAGE = 0x3,
	ENUM_PASTPMOTION_MAX = 0x4,
};

enum pastp_actman_mode
{
	MODE_PASTPACT_INIT = 0x0,
	MODE_PASTPACT_IDLE = 0x1,
	MODE_PASTPACT_END = 0x2,
};

enum GG_ROM
{
	GG_ROM_SONIC_THE_HEDGEHOG = 0x0,
	GG_ROM_SONIC_DRIFTRACING = 0x1,
	GG_ROM_SONIC_CHAOS = 0x2,
	GG_ROM_SONIC_SPINBALL = 0x3,
	GG_ROM_SONIC_LABYRINTH = 0x4,
	GG_ROM_SONIC_THE_HEDGEHOG_2 = 0x5,
	GG_ROM_DR_ROBOTONIK = 0x6,
	GG_ROM_SONIC_THE_HEDGEHOG_TRIPLE_TROUBLE = 0x7,
	GG_ROM_SONIC_DRIFT_2 = 0x8,
	GG_ROM_TALS_SKYPATROL = 0x9,
	GG_ROM_SONIC_BLAST = 0xA,
	GG_ROM_TAILS_ADVENTURE = 0xB,
	GG_ROM_NUM = 0xC,
};

enum MD_CHAOS
{
	MD_CHAOS_INIT = 0x0,
	MD_CHAOS_STND = 0x1,
	MD_CHAOS_MOVE = 0x2,
	MD_CHAOS_MOVE_AP = 0x3,
	MD_CHAOS_SJUMP = 0x4,
	MD_CHAOS_W_YMOVE = 0x5,
	MD_CHAOS_PUNCH = 0x6,
	MD_CHAOS_DAMAGE = 0x7,
	MD_CHAOS_OBJ2W = 0x8,
	MD_CHAOS_W2OBJ = 0x9,
	MD_CHAOS_JUMP = 0xA,
	MD_CHAOS_ROLLATTACK = 0xB,
	MD_CHAOS_ONTHEPOLE = 0xC,
	MD_CHAOS_PUNCH_P = 0xD,
	MD_CHAOS_CRUSH_CAR = 0xE,
	MD_CHAOS_MOVE_W = 0xF,
	MD_CHAOS_MOVE_WR = 0x10,
	MD_CHAOS_ATTACK2 = 0x11,
	MD_CHAOS_GUARD = 0x12,
	MD_CHAOS_FALL = 0x13,
	MD_CHAOS_EV_WAIT = 0x14,
	MD_CHAOS_EV_WATER = 0x15,
	MD_CHAOS_EV_OBJ2W = 0x16,
	MD_CHAOS_EV_W2OBJ = 0x17,
	MD_CHAOS_EDIT = 0x18,
};

enum BUBBLE_C0
{
	BUBBLE_C0_HEAD = 0x0,
	BUBBLE_C0_BODY = 0x1,
	BUBBLE_C0_KOSHI = 0x2,
	BUBBLE_C0_ARM00 = 0x3,
	BUBBLE_C0_ARM10 = 0x4,
	BUBBLE_C0_ARM20 = 0x5,
	BUBBLE_C0_ARM01 = 0x6,
	BUBBLE_C0_ARM11 = 0x7,
	BUBBLE_C0_ARM21 = 0x8,
	BUBBLE_C0_FOOT00 = 0x9,
	BUBBLE_C0_FOOT10 = 0xA,
	BUBBLE_C0_FOOT20 = 0xB,
	BUBBLE_C0_FOOT01 = 0xC,
	BUBBLE_C0_FOOT11 = 0xD,
	BUBBLE_C0_FOOT21 = 0xE,
	BUBBLE_C0_ARM30 = 0xF,
	BUBBLE_C0_FOOT30 = 0x10,
	BUBBLE_C0_FOOT40 = 0x11,
	BUBBLE_C0_ARM31 = 0x12,
	BUBBLE_C0_FOOT31 = 0x13,
	BUBBLE_C0_FOOT41 = 0x14,
	BUBBLE_C0_NUM = 0x15,
};

enum COLLI_C0
{
	COLLI_C0_HEAD = 0x0,
	COLLI_C0_BODY = 0x1,
	COLLI_C0_GUARD = 0x2,
	COLLI_C0_ATTACK_RARM = 0x3,
	COLLI_C0_ATTACK_ROLL = 0x4,
	COLLI_C0_NUM = 0x5,
};

enum COLLIMD_C0
{
	COLLIMD_C0_STAND = 0x0,
	COLLIMD_C0_PUNCH = 0x1,
	COLLIMD_C0_ROLL = 0x2,
	COLLIMD_C0_GUARD = 0x3,
	COLLIMD_C0_WATER = 0x4,
	COLLIMD_C0_MORPH = 0x5,
	COLLIMD_C0_NO = 0x6,
	COLLIMD_C0_NUM = 0x7,
};

enum SoundIDs
{
	SE_DAMAGE = 0x0,
	SE_CURSOR = 0x1,
	SE_DECIDE = 0x2,
	SE_PAUSE = 0x3,
	SE_COUNT = 0x4,
	SE_COUNTUP = 0x5,
	SE_NORMBARRIER = 0x6,
	SE_RING = 0x7,
	SE_TIMESTOP = 0x8,
	SE_SPRING = 0x9,
	SE_SAVE = 0xA,
	SE_ITEMBOX = 0xB,
	SE_ITEMGET = 0xC,
	SE_SWITCH = 0xD,
	SE_MOTINOR = 0xE,
	SE_PUSHPULL = 0xF,
	SE_BREAK = 0x10,
	SE_P_JUMP = 0x11,
	SE_P_BRAKE = 0x12,
	SE_LAND = 0x13,
	SE_THROW = 0x14,
	SE_ZOOMUP = 0x15,
	SE_ZOOMOUT = 0x16,
	SE_DAMAGE2 = 0x17,
	SE_DUMMY24 = 0x18,
	SE_BOMB = 0x19,
	SE_BOMB2 = 0x1A,
	SE_HITENEMY = 0x1B,
	SE_GETMINIMAL = 0x1C,
	SE_P_JUMP2 = 0x1D,
	SE_P_BRAKE2 = 0x1E,
	SE_P_FT1 = 0x1F,
	SE_P_FT2 = 0x20,
	SE_P_FT3 = 0x21,
	SE_P_FT4 = 0x22,
	SE_P_FT5 = 0x23,
	SE_P_FT6 = 0x24,
	SE_P_FT7 = 0x25,
	SE_P_FT8 = 0x26,
	SE_BANK_1_CS = 0x27,
	SE_CS_DUMMY00 = 0x28,
	SE_CS_BRIDGE = 0x29,
	SE_CS_DAIBREAK = 0x2A,
	SE_CS_YAMABREAK = 0x2B,
	SE_CS_IWABREAK = 0x2C,
	SE_CS_CHONPA = 0x2D,
	SE_CS_RUBBER = 0x2E,
	SE_CS_INWATER = 0x2F,
	SE_CS_SWIM = 0x30,
	SE_CS_FENCE = 0x31,
	SE_CS_BREAK = 0x32,
	SE_CS_JUMPER = 0x33,
	SE_CS_BUSH = 0x34,
	SE_BANK_1_WV = 0x35,
	SE_WV_DUMMY00 = 0x36,
	SE_WV_TRAMP = 0x37,
	SE_WV_UPWIND = 0x38,
	SE_WV_ELEV = 0x39,
	SE_WV_DOOR = 0x3A,
	SE_WV_WIND = 0x3B,
	SE_WV_BRIDGE = 0x3C,
	SE_WV_TOR_FAR = 0x3D,
	SE_WV_TOR_NEAR = 0x3E,
	SE_WV_TORNADO = 0x3F,
	SE_WV_BRKBRIDGE = 0x40,
	SE_BANK_1_TP = 0x41,
	SE_TP_STRIKE = 0x42,
	SE_TP_MERRYGOROUND = 0x43,
	SE_TP_BOWLSHOT = 0x44,
	SE_TP_BOWL = 0x45,
	SE_TP_BOWLBRK = 0x46,
	SE_TP_PANEL = 0x47,
	SE_TP_DUMMY00 = 0x48,
	SE_TP_CARTF = 0x49,
	SE_TP_CART = 0x4A,
	SE_TP_BALOON = 0x4B,
	SE_TP_COASTER = 0x4C,
	SE_TP_COASTERACC = 0x4D,
	SE_TP_BUYON_F = 0x4E,
	SE_TP_BUYON_S = 0x4F,
	SE_TP_BUYON_W = 0x50,
	SE_TP_BUYON_R = 0x51,
	SE_TP_SARU = 0x52,
	SE_TP_BOWLING = 0x53,
	SE_TP_BEAM = 0x54,
	SE_TP_CARTSTOP = 0x55,
	SE_TP_SHUTTER1 = 0x56,
	SE_TP_SHUTTER2 = 0x57,
	SE_TP_SHUTTER3 = 0x58,
	SE_TP_SPACESHIP = 0x59,
	SE_TP_ASTEROID = 0x5A,
	SE_BANK_1_HW = 0x5B,
	SE_HW_DUMMY00 = 0x5C,
	SE_HW_CANAL = 0x5D,
	SE_HW_GLASS = 0x5E,
	SE_HW_GLASSBREAK = 0x5F,
	SE_HW_HELI = 0x60,
	SE_HW_ENGINE = 0x61,
	SE_HW_BRAKE = 0x62,
	SE_HW_CRASH = 0x63,
	SE_HW_CLANK = 0x64,
	SE_HW_CLSTOP = 0x65,
	SE_HW_ELEV = 0x66,
	SE_HW_ESCASTART = 0x67,
	SE_HW_ESCASTOP = 0x68,
	SE_HW_FOUNTAIN = 0x69,
	SE_HW_FJUMP = 0x6A,
	SE_HW_SIREN = 0x6B,
	SE_HW_SIREN_Q2 = 0x6C,
	SE_HW_SIREN_Q3 = 0x6D,
	SE_HW_SIREN_Q4 = 0x6E,
	SE_HW_TANKBOMB = 0x6F,
	SE_HW_TANKDEST = 0x70,
	SE_HW_KANHIT = 0x71,
	SE_HW_KANDEST = 0x72,
	SE_HW_BUSH = 0x73,
	SE_HW_NEON = 0x74,
	SE_HW_CLOCK = 0x75,
	SE_HW_PYLON = 0x76,
	SE_HW_PUPU = 0x77,
	SE_HW_EXTHIT = 0x78,
	SE_HW_EXTWATER = 0x79,
	SE_HW_HELI_Q2 = 0x7A,
	SE_BANK_1_DM = 0x7B,
	SE_DM_BREAKMT = 0x7C,
	SE_DM_HAMMER = 0x7D,
	SE_DM_MAGMA = 0x7E,
	SE_DM_BREAKROCK = 0x7F,
	SE_DM_ROCKBOMB = 0x80,
	SE_DM_MAGMAPOKO = 0x81,
	SE_DM_MAGMAUP = 0x82,
	SE_DM_ESHOCK = 0x83,
	SE_DM_KASSHA = 0x84,
	SE_DM_PLATHOME = 0x85,
	SE_DM_BAT = 0x86,
	SE_DM_DUMMY00 = 0x87,
	SE_DM_DUMMY01 = 0x88,
	SE_DM_DUMMY02 = 0x89,
	SE_TG_BOMB = 0x8A,
	SE_TG_DUMMY03 = 0x8B,
	SE_TG_DUMMY04 = 0x8C,
	SE_TG_DUMMY05 = 0x8D,
	SE_TG_DUMMY06 = 0x8E,
	SE_TG_DUMMY07 = 0x8F,
	SE_TG_DUMMY08 = 0x90,
	SE_TG_DUMMY09 = 0x91,
	SE_TG_DUMMY0A = 0x92,
	SE_TG_DUMMY0B = 0x93,
	SE_TG_DUMMY0C = 0x94,
	SE_TG_DUMMY0D = 0x95,
	SE_TG_DUMMY0E = 0x96,
	SE_TG_TELOP = 0x97,
	SE_TG_HOVER = 0x98,
	SE_TG_FIRE = 0x99,
	SE_TG_MOVE = 0x9A,
	SE_TG_ITE = 0x9B,
	SE_TG_ELEC = 0x9C,
	SE_TG_DUMMY0F = 0x9D,
	SE_TG_HIT = 0x9E,
	SE_BANK_1_SD = 0x9F,
	SE_SD_CANH_SIREN = 0xA0,
	SE_SD_CANST_MOVE = 0xA1,
	SE_SD_CAN_STOP = 0xA2,
	SE_SD_CANB_FIRE = 0xA3,
	SE_SD_UNTEI_BROKEN = 0xA4,
	SE_SD_POLH_BROKEN = 0xA5,
	SE_SD_CANH_APPEAR = 0xA6,
	SE_SD_CANH_ROT = 0xA7,
	SE_SD_CANH_FIRE = 0xA8,
	SE_SD_CANH_BOMB = 0xA9,
	SE_SD_CANH_HIT = 0xAA,
	SE_SD_CANS_MOVE = 0xAB,
	SE_SD_CANS_FIRE = 0xAC,
	SE_SD_CANM_MOVE = 0xAD,
	SE_SD_CANM_FIRE = 0xAE,
	SE_SD_GRAB = 0xAF,
	SE_SD_RANE_SINK = 0xB0,
	SE_SD_RANE_BOMB = 0xB1,
	SE_SD_DRUM_BOUND = 0xB2,
	SE_SD_DRUM_BOMB = 0xB3,
	SE_SD_CATCHER = 0xB4,
	SE_SD_CONTAINER = 0xB5,
	SE_SD_FALL = 0xB6,
	SE_SD_JOYSTICK = 0xB7,
	SE_SD_CANST_FIRE = 0xB8,
	SE_SD_CANST_PLAYER = 0xB9,
	SE_SD_EXIT = 0xBA,
	SE_SD_DUMMY27 = 0xBB,
	SE_SD_DUMMY28 = 0xBC,
	SE_SDE_EGGMAN_DOWN = 0xBD,
	SE_SDE_EGGMAN_UP = 0xBE,
	SE_BANK_1_LW = 0xBF,
	SE_LW_DUMMY00 = 0xC0,
	SE_LW_POLE = 0xC1,
	SE_LW_DOOR = 0xC2,
	SE_LW_SURFACE = 0xC3,
	SE_LW_SNAKE = 0xC4,
	SE_LW_MIRROR = 0xC5,
	SE_LW_WATER = 0xC6,
	SE_LW_STONE = 0xC7,
	SE_LW_PANEL = 0xC8,
	SE_LW_ARROW = 0xC9,
	SE_LW_POLEBOMB = 0xCA,
	SE_LW_COLONY = 0xCB,
	SE_LW_NEEDLE = 0xCC,
	SE_LW_SWITCH = 0xCD,
	SE_LW_SIGESIGE = 0xCE,
	SE_BANK_1_IC = 0xCF,
	SE_IC_DUMMY = 0xD0,
	SE_IC_IPBREAK = 0xD1,
	SE_IC_IPFALL = 0xD2,
	SE_IC_ICEBREAK1 = 0xD3,
	SE_IC_IPQUAKE = 0xD4,
	SE_IC_WATER = 0xD5,
	SE_IC_WFREEZE = 0xD6,
	SE_IC_ICEBREAK2 = 0xD7,
	SE_IC_ICEBREAK3 = 0xD8,
	SE_IC_PFREEZE = 0xD9,
	SE_IC_SLIP1 = 0xDA,
	SE_IC_IPKICK = 0xDB,
	SE_IC_BRDOWN1 = 0xDC,
	SE_IC_BRDOWN2 = 0xDD,
	SE_IC_ITABREAK = 0xDE,
	SE_IC_NADARE = 0xDF,
	SE_IC_CRBREAK = 0xE0,
	SE_IC_SLIP2 = 0xE1,
	SE_IC_SLIP3 = 0xE2,
	SE_IC_SLIP4 = 0xE3,
	SE_IC_SLIP5 = 0xE4,
	SE_IC_SNOWFALL = 0xE5,
	SE_IC_JUMP = 0xE6,
	SE_IC_JUMPWIND = 0xE7,
	SE_IC_TOSSBOMB = 0xE8,
	SE_IC_BOMB = 0xE9,
	SE_IC_BOMBER = 0xEA,
	SE_IC_WOODHIT = 0xEB,
	SE_IC_ICEHIT = 0xEC,
	SE_IC_EDGE = 0xED,
	SE_BANK_1_CA = 0xEE,
	SE_CA_NIGHTSRING = 0xEF,
	SE_CA_BRKCAPTURE = 0xF0,
	SE_CA_PUTIDEA = 0xF1,
	SE_CA_DROPTARG = 0xF2,
	SE_CA_YAKU = 0xF3,
	SE_CA_SYAKU = 0xF4,
	SE_CA_BUMPER = 0xF5,
	SE_CA_FLIPPER = 0xF6,
	SE_CA_SRANE = 0xF7,
	SE_CA_SHOT = 0xF8,
	SE_CA_OUTFALL = 0xF9,
	SE_CA_GIMMICK = 0xFA,
	SE_CA_STOPPER = 0xFB,
	SE_CA_START = 0xFC,
	SE_CA_SLOT = 0xFD,
	SE_CA_SLOTSW = 0xFE,
	SE_CA_SLOTYAKU = 0xFF,
	SE_CA_SLOYDAME = 0x100,
	SE_CA_FALLSHOOTER = 0x101,
	SE_CA_FALLBALL = 0x102,
	SE_CA_FAN_GOOD = 0x103,
	SE_CA_FAN_BAD = 0x104,
	SE_CA_ROT = 0x105,
	SE_CA_CLEAN = 0x106,
	SE_CA_FUN = 0x107,
	SE_CA_FUNWIND = 0x108,
	SE_CA_MANHOLE = 0x109,
	SE_CA_SHOWERJ = 0x10A,
	SE_CA_SHOWER = 0x10B,
	SE_CA_AUTODOOR = 0x10C,
	SE_CA_TRANS = 0x10D,
	SE_CA_TRANSP = 0x10E,
	SE_CA_SH_MOTOR = 0x10F,
	SE_CA_SH_CATCH = 0x110,
	SE_CA_SH_COUNTER = 0x111,
	SE_CA_GEAR = 0x112,
	SE_CA_NEON = 0x113,
	SE_CA_LION = 0x114,
	SE_CA_LIONHAND = 0x115,
	SE_CA_H = 0x116,
	SE_BANK_1_FE = 0x117,
	SE_FE_DUMMY00 = 0x118,
	SE_FE_F_PIPE = 0x119,
	SE_FE_PIPEOUT = 0x11A,
	SE_FE_TARGET = 0x11B,
	SE_FE_TARGMOVE = 0x11C,
	SE_FE_TARGDEST = 0x11D,
	SE_FE_ROLLER = 0x11E,
	SE_FE_VAC = 0x11F,
	SE_FE_BELT = 0x120,
	SE_FE_FAN = 0x121,
	SE_FE_CANBOMB = 0x122,
	SE_FE_DOOR = 0x123,
	SE_FE_WALLDEST = 0x124,
	SE_FE_SHUTTER = 0x125,
	SE_FE_ELEV = 0x126,
	SE_FE_LASER = 0x127,
	SE_FE_ARM = 0x128,
	SE_FE_ARMHIT = 0x129,
	SE_FE_BEEP = 0x12A,
	SE_FE_GACHABOMB = 0x12B,
	SE_FE_ELEVARM = 0x12C,
	SE_FE_HATCH = 0x12D,
	SE_FE_HAMMER = 0x12E,
	SE_FE_STOP = 0x12F,
	SE_BANK_1_HS = 0x130,
	SE_HS_TELOP = 0x131,
	SE_HS_ELV = 0x132,
	SE_HS_ELVSTOP = 0x133,
	SE_HS_HANDLE = 0x134,
	SE_HS_POOL = 0x135,
	SE_HS_GLASS = 0x136,
	SE_HS_ALERT = 0x137,
	SE_HS_LAMP = 0x138,
	SE_HS_STAIR = 0x139,
	SE_HS_SEN = 0x13A,
	SE_HS_WATER = 0x13B,
	SE_HS_HANGUP = 0x13C,
	SE_HS_PLUGPULL = 0x13D,
	SE_HS_PLUGIN = 0x13E,
	SE_HS_PLUGOUT = 0x13F,
	SE_HS_PLUGYURA = 0x140,
	SE_HS_GEARROT = 0x141,
	SE_HS_GEARSTART = 0x142,
	SE_HS_GEARSTOP = 0x143,
	SE_HS_MONITOR = 0x144,
	SE_HS_CARGOALERT = 0x145,
	SE_HS_CARGOSTOP = 0x146,
	SE_HS_DOOR = 0x147,
	SE_HS_ROTATE = 0x148,
	SE_TG_BOMB2 = 0x149,
	SE_BANK_1_CZ = 0x14A,
	SE_CZ_TELOP = 0x14B,
	SE_CZ_FOOT = 0x14C,
	SE_CZ_CHARGE = 0x14D,
	SE_CZ_ARMATK = 0x14E,
	SE_CZ_ARMROT = 0x14F,
	SE_CZ_PATBOMB = 0x150,
	SE_CZ_JUMP = 0x151,
	SE_CZ_REFLECT = 0x152,
	SE_CZ_HIT = 0x153,
	SE_CZ_WBOUND = 0x154,
	SE_CZ_REGEN = 0x155,
	SE_CZ_FOOT2 = 0x156,
	SE_CZ_BALLFORM = 0x157,
	SE_CZ_BOUND = 0x158,
	SE_CZ_REFLECT2 = 0x159,
	SE_CZ_EXPLODE = 0x15A,
	SE_CZ_BOUND_MINI = 0x15B,
	SE_CZ_REFLECT_MINI = 0x15C,
	SE_CZ_LIQUID = 0x15D,
	SE_CZ_LIQRET = 0x15E,
	SE_CZ_ARMATK2 = 0x15F,
	SE_CZ_SHAN = 0x160,
	SE_CZ_ELEV = 0x161,
	SE_BANK_1_C4 = 0x162,
	SE_C4_TELOP = 0x163,
	SE_C4_DUMMY00 = 0x164,
	SE_C4_CHARGE = 0x165,
	SE_C4_DUMMY01 = 0x166,
	SE_C4_DUMMY02 = 0x167,
	SE_C4_DUMMY03 = 0x168,
	SE_C4_DUMMY04 = 0x169,
	SE_C4_REFLECT = 0x16A,
	SE_C4_HIT = 0x16B,
	SE_C4_DUMMY05 = 0x16C,
	SE_C4_REGEN = 0x16D,
	SE_C4_INSWAMP = 0x16E,
	SE_C4_SWAMPWALK = 0x16F,
	SE_C4_SWAMPSINK = 0x170,
	SE_C4_SWAMPSWIM = 0x171,
	SE_C4_BSINK = 0x172,
	SE_C4_BFLOW = 0x173,
	SE_C4_WHIP = 0x174,
	SE_C4_WATER = 0x175,
	SE_C4_POISON = 0x176,
	SE_C4_WBUSTER = 0x177,
	SE_C4_CFLOW = 0x178,
	SE_BANK_1_C6 = 0x179,
	SE_C6_TELOP = 0x17A,
	SE_C6_DUMMY00 = 0x17B,
	SE_C6_CHARGE = 0x17C,
	SE_C6_ARMATK = 0x17D,
	SE_C6_DUMMY02 = 0x17E,
	SE_C6_DUMMY03 = 0x17F,
	SE_C6_JUMP = 0x180,
	SE_C6_REFLECT = 0x181,
	SE_C6_HIT = 0x182,
	SE_C6_DUMMY04 = 0x183,
	SE_C6_REGEN = 0x184,
	SE_C6_LAND = 0x185,
	SE_C6_WAVE = 0x186,
	SE_C6_TAIL1 = 0x187,
	SE_C6_TAIL2 = 0x188,
	SE_C6_VACCUM = 0x189,
	SE_C6_ARM = 0x18A,
	SE_C6_SATE = 0x18B,
	SE_C6_LIQUID = 0x18C,
	SE_C6_SATESHOT = 0x18D,
	SE_C6_FREEZE = 0x18E,
	SE_C6_SATEFALL = 0x18F,
	SE_C6_SATEBOMB = 0x190,
	SE_C6_ICEBOMB = 0x191,
	SE_C6_GLASSBOMB = 0x192,
	SE_C6_STAGEBOMB = 0x193,
	SE_C6_HIRUMI = 0x194,
	SE_C6_CANNON = 0x195,
	SE_C6_EGGMOBILE = 0x196,
	SE_C6_ICEBOMB2 = 0x197,
	SE_BANK_1_PCA = 0x198,
	SE_PCA_TELOP = 0x199,
	SE_PCA_DUMMY00 = 0x19A,
	SE_PCA_DUMMY01 = 0x19B,
	SE_PCA_DUMMY02 = 0x19C,
	SE_PCA_DUMMY03 = 0x19D,
	SE_PCA_DUMMY04 = 0x19E,
	SE_PCA_DUMMY05 = 0x19F,
	SE_PCA_DUMMY06 = 0x1A0,
	SE_PCA_HIT = 0x1A1,
	SE_PCA_DUMMY07 = 0x1A2,
	SE_PCA_DUMMY08 = 0x1A3,
	SE_PCA_BARBRK = 0x1A4,
	SE_PCA_BARREGEN = 0x1A5,
	SE_PCA_ARMBRK = 0x1A6,
	SE_PCA_WATER = 0x1A7,
	SE_PCA_CLEAN = 0x1A8,
	SE_PCA_BREAK = 0x1A9,
	SE_PCA_RING = 0x1AA,
	SE_BANK_1_PCB = 0x1AB,
	SE_PCB_TELOP = 0x1AC,
	SE_PCB_DUMMY00 = 0x1AD,
	SE_PCB_CHARGE = 0x1AE,
	SE_PCB_DUMMY02 = 0x1AF,
	SE_PCB_DUMMY03 = 0x1B0,
	SE_PCB_DUMMY04 = 0x1B1,
	SE_PCB_DUMMY05 = 0x1B2,
	SE_PCB_DUMMY06 = 0x1B3,
	SE_PCB_HIT = 0x1B4,
	SE_PCB_DUMMY07 = 0x1B5,
	SE_PCB_DUMMY08 = 0x1B6,
	SE_PCB_BREATH = 0x1B7,
	SE_PCB_ARMATTACK = 0x1B8,
	SE_PCB_TORATTACK = 0x1B9,
	SE_PCB_ARMWATER = 0x1BA,
	SE_PCB_BALLBOMB = 0x1BB,
	SE_PCB_ATKHIT = 0x1BC,
	SE_PCB_BUILDBRK = 0x1BD,
	SE_PCB_GAO1 = 0x1BE,
	SE_PCB_GAO2 = 0x1BF,
	SE_PCB_BODYHIT = 0x1C0,
	SE_PCB_SONICUP = 0x1C1,
	SE_PCB_BRAINBRK = 0x1C2,
	SE_PCB_SONICOUT = 0x1C3,
	SE_PCB_DEEP = 0x1C4,
	SE_BANK_1_M1 = 0x1C5,
	SE_M1_TELOP = 0x1C6,
	SE_M1_MISSILE = 0x1C7,
	SE_M1_BOMB = 0x1C8,
	SE_M1_JET = 0x1C9,
	SE_M1_JET_S = 0x1CA,
	SE_M1_JET_L = 0x1CB,
	SE_M1_ENERGY = 0x1CC,
	SE_M1_COLLI = 0x1CD,
	SE_M1_WAIT = 0x1CE,
	SE_M1_IMPACT = 0x1CF,
	SE_M1_DEST = 0x1D0,
	SE_M1_HIT = 0x1D1,
	SE_M1_DTAME = 0x1D2,
	SE_BANK_1_M2 = 0x1D3,
	SE_M2_TELOP = 0x1D4,
	SE_M2_LAND = 0x1D5,
	SE_M2_KANSETSU = 0x1D6,
	SE_M2_WALK = 0x1D7,
	SE_M2_STAMP = 0x1D8,
	SE_M2_B_SHOT = 0x1D9,
	SE_M2_B_FALL = 0x1DA,
	SE_M2_B_BOMB = 0x1DB,
	SE_M2_FLAME = 0x1DC,
	SE_M2_BALANCE_L = 0x1DD,
	SE_M2_BALANCE = 0x1DE,
	SE_M2_KISIMI = 0x1DF,
	SE_M2_DAMAGE = 0x1E0,
	SE_M2_GIMOUT = 0x1E1,
	SE_M2_JUMP = 0x1E2,
	SE_M2_BOMB = 0x1E3,
	SE_M2_SB_FALL = 0x1E4,
	SE_M2_SB_BOMB = 0x1E5,
	SE_BANK_1_M3 = 0x1E6,
	SE_M3_TELOP = 0x1E7,
	SE_M3_BEAMCHARGE = 0x1E8,
	SE_M3_BEAMSHOT = 0x1E9,
	SE_M3_FIRE = 0x1EA,
	SE_M3_SMOKE = 0x1EB,
	SE_M3_DUMMY00 = 0x1EC,
	SE_M3_SHIELD = 0x1ED,
	SE_M3_COCKPIT = 0x1EE,
	SE_M3_ENERGYCHARGE = 0x1EF,
	SE_M3_ENERGYSOLID = 0x1F0,
	SE_M3_ENERGYSHOT = 0x1F1,
	SE_M3_ENERGYBOMB = 0x1F2,
	SE_M3_NEEDLE = 0x1F3,
	SE_M3_NEEDLEROT = 0x1F4,
	SE_M3_DUMMY01 = 0x1F5,
	SE_M3_GRBOMB = 0x1F6,
	SE_M3_DUMMY02 = 0x1F7,
	SE_M3_CANBOMB = 0x1F8,
	SE_M3_COCKHIT = 0x1F9,
	SE_M3_FINALBOMB = 0x1FA,
	SE_BANK_1_ER = 0x1FB,
	SE_ER_TELOP = 0x1FC,
	SE_ER_HOVER = 0x1FD,
	SE_ER_FIRE = 0x1FE,
	SE_ER_MOVE = 0x1FF,
	SE_ER_ITE = 0x200,
	SE_ER_ELEC = 0x201,
	SE_ER_BOMB = 0x202,
	SE_ER_HIT = 0x203,
	SE_ER_ENERGY = 0x204,
	SE_ER_EBULLET = 0x205,
	SE_ER_ILLUSION = 0x206,
	SE_ER_CHARGE = 0x207,
	SE_ER_REFLECT = 0x208,
	SE_BANK_1_SS = 0x209,
	SE_SS_CUBEIN = 0x20A,
	SE_SS_TRAINDOOR = 0x20B,
	SE_SS_DUMMY00 = 0x20C,
	SE_SS_DUMMY01 = 0x20D,
	SE_SS_DUMMY02 = 0x20E,
	SE_SS_DUMMY03 = 0x20F,
	SE_SS_DOOR1 = 0x210,
	SE_SS_DOOR2 = 0x211,
	SE_SS_AUTODOOR = 0x212,
	SE_SS_ELVDOOR = 0x213,
	SE_SS_ELVATTEN = 0x214,
	SE_SS_PUTEGG = 0x215,
	SE_SS_FENCECLOSE = 0x216,
	SE_SS_FENCEDOWN = 0x217,
	SE_SS_FENCEUP = 0x218,
	SE_SS_NEOELV = 0x219,
	SE_SS_BALIHIT = 0x21A,
	SE_SS_BALIBOMB = 0x21B,
	SE_SS_ENGINE = 0x21C,
	SE_SS_BRAKE = 0x21D,
	SE_SS_CARHIT = 0x21E,
	SE_SS_BUSH = 0x21F,
	SE_SS_NEON = 0x220,
	SE_SS_PUPU = 0x221,
	SE_SS_EXTBOMB = 0x222,
	SE_SS_EXTWATER = 0x223,
	SE_SS_RING = 0x224,
	SE_SS_ENGINE_Q2 = 0x225,
	SE_SS_ENGINE_Q3 = 0x226,
	SE_SS_ENGINE_Q4 = 0x227,
	SE_BANK_1_EC = 0x228,
	SE_EC_EM_SEAT = 0x229,
	SE_EC_EM_FAILED = 0x22A,
	SE_EC_FUTA = 0x22B,
	SE_EC_FIRE = 0x22C,
	SE_EC_P_FIRE = 0x22D,
	SE_EC_LADDER = 0x22E,
	SE_EC_LIFT = 0x22F,
	SE_EC_LIFT_MOVE = 0x230,
	SE_EC_SD_ENTRY = 0x231,
	SE_EC_MR_FUTA = 0x232,
	SE_EC_MR = 0x233,
	SE_EC_MR_MOVE = 0x234,
	SE_EC_MR_BRAKE = 0x235,
	SE_EC_SD_KNUCK = 0x236,
	SE_EC_RING = 0x237,
	SE_EC_EM_BUTTON = 0x238,
	SE_EC_MIURA = 0x239,
	SE_EC_HAMMERSW = 0x23A,
	SE_EC_MOLE = 0x23B,
	SE_EC_SMOLE = 0x23C,
	SE_EC_BMOLE = 0x23D,
	SE_EC_EMOLE = 0x23E,
	SE_EC_MOLESTART = 0x23F,
	SE_EC_TRANSFORM = 0x240,
	SE_EC_DOOR = 0x241,
	SE_EC_ROCKET = 0x242,
	SE_EC_CLEANER = 0x243,
	SE_BANK_1_MR = 0x244,
	SE_MR_EM_FAILED = 0x245,
	SE_MR_CUBESET = 0x246,
	SE_MR_LADDER = 0x247,
	SE_MR_RING = 0x248,
	SE_MR_MIURA = 0x249,
	SE_MR_DOOR = 0x24A,
	SE_MR_TAKI = 0x24B,
	SE_MR_RIVER = 0x24C,
	SE_MR_TOLOCOS = 0x24D,
	SE_MR_TOLOCO = 0x24E,
	SE_MR_DUMMY00 = 0x24F,
	SE_MR_SAND = 0x250,
	SE_MR_ROCK = 0x251,
	SE_MR_ROCKDOOR = 0x252,
	SE_MR_JUNGLE1 = 0x253,
	SE_MR_JUNGLE2 = 0x254,
	SE_MR_BUSH = 0x255,
	SE_MR_GAN = 0x256,
	SE_BANK_1_CH = 0x257,
	SE_CH_EAT = 0x258,
	SE_CH_PICK = 0x259,
	SE_CH_FOOTSTEP_R = 0x25A,
	SE_CH_FOOTSTEP_L = 0x25B,
	SE_CH_CAPTURE_KYUKYU = 0x25C,
	SE_CH_CAPTURE_KYUPIN = 0x25D,
	SE_CH_HOGE0 = 0x25E,
	SE_CH_PON = 0x25F,
	SE_CH_TREE_YUSA = 0x260,
	SE_CH_FRUIT_FALL = 0x261,
	SE_CH_KOKE = 0x262,
	SE_CH_JUMP = 0x263,
	SE_CH_FLY = 0x264,
	SE_CH_MABATAKI = 0x265,
	SE_CH_HIRAMEKI = 0x266,
	SE_CH_KONKON = 0x267,
	SE_CH_UMARERU = 0x268,
	SE_CH_EGG_CRASH = 0x269,
	SE_CH_GOO = 0x26A,
	SE_CH_PHOO = 0x26B,
	SE_CH_NYOKI = 0x26C,
	SE_CH_PORIPORI = 0x26D,
	SE_CH_HANABI_PACHI = 0x26E,
	SE_CH_HAKYUSYU = 0x26F,
	SE_CH_SAVE = 0x270,
	SE_CH_VM_DERU = 0x271,
	SE_CH_FALL = 0x272,
	SE_CH_HANABI_SYUU = 0x273,
	SE_CH_MAYU_MAKING = 0x274,
	SE_CH_MAYU_DERU = 0x275,
	SE_CH_FIRE = 0x276,
	SE_CH_SWIM = 0x277,
	SE_CH_DOPUN = 0x278,
	SE_CH_CHAPU = 0x279,
	SE_CH_SYABON = 0x27A,
	SE_CH_SUNAHORI = 0x27B,
	SE_CH_TATAKU = 0x27C,
	SE_CH_HOUKI = 0x27D,
	SE_CH_RAKUGAKI = 0x27E,
	SE_CH_CRACKER = 0x27F,
	SE_CH_GARAGARA = 0x280,
	SE_CH_HANABI_DOKAN = 0x281,
	SE_CH_BIKKURIBAKO = 0x282,
	SE_CH_BOING = 0x283,
	SE_CH_LION = 0x284,
	SE_CH_GORILLA = 0x285,
	SE_CH_AZARASHI = 0x286,
	SE_CH_BIRD = 0x287,
	SE_CH_SHEEP = 0x288,
	SE_CH_BAT = 0x289,
	SE_CH_HOGE1 = 0x28A,
	SE_CH_RAKKO = 0x28B,
	SE_CH_ACROBAT = 0x28C,
	SE_CH_AZARASHI2 = 0x28D,
	SE_CH_KUJAKU = 0x28E,
	SE_CH_TUBAME = 0x28F,
	SE_CH_OUMU = 0x290,
	SE_CH_BANBI = 0x291,
	SE_CH_GORILLA2 = 0x292,
	SE_CH_LION2 = 0x293,
	SE_CH_ZOU = 0x294,
	SE_CH_BELL = 0x295,
	SE_CH_BASS = 0x296,
	SE_CH_BRASS = 0x297,
	SE_CH_HOGE2 = 0x298,
	SE_CH_OBOE = 0x299,
	SE_CH_WARP = 0x29A,
	SE_CH_OSANPO_FUTA_N = 0x29B,
	SE_CH_OSANPO_FUTA_H = 0x29C,
	SE_CH_OSANPO_FUTA_D = 0x29D,
	SE_CH_WARP2 = 0x29E,
	SE_CH_BASS2 = 0x29F,
	SE_CH_WOODBASS = 0x2A0,
	SE_CH_FLUTE = 0x2A1,
	SE_CH_PIPEORGAN = 0x2A2,
	SE_CH_TRUMPET = 0x2A3,
	SE_CH_VIBRAPHONE = 0x2A4,
	SE_CH_PIANO = 0x2A5,
	SE_CH_HOGE3 = 0x2A6,
	SE_CH_HOGE4 = 0x2A7,
	SE_CH_ELEVATOR_UP = 0x2A8,
	SE_CH_ELEVATOR_STOP = 0x2A9,
	SE_CH_ELEVATOR_FUTA = 0x2AA,
	SE_CH_GATE_OPEN = 0x2AB,
	SE_CH_HOGE5 = 0x2AC,
	SE_CH_DORE_OPEN = 0x2AD,
	SE_CH_SPRING = 0x2AE,
	SE_CH_HOGE6 = 0x2AF,
	SE_CH_BEACH = 0x2B0,
	SE_CH_HOGE7 = 0x2B1,
	SE_CH_START = 0x2B2,
	SE_CH_TAIKO = 0x2B3,
	SE_CH_RAPPA = 0x2B4,
	SE_CH_FUE = 0x2B5,
	SE_CH_THINBAL = 0x2B6,
	SE_CH_AGOGOBELL = 0x2B7,
	SE_CH_TAMBOURINE = 0x2B8,
	SE_CH_BONGO = 0x2B9,
	SE_CH_SUZU = 0x2BA,
	SE_BANK_1_CT = 0x2BB,
	SE_CT_WALLHIT = 0x2BC,
	SE_CT_READY = 0x2BD,
	SE_CT_START = 0x2BE,
	SE_CT_GOAL = 0x2BF,
	SE_CT_FLOW = 0x2C0,
	SE_BANK_1_SHT = 0x2C1,
	SE_SHT_FMINE = 0x2C2,
	SE_SHT_FLY_PP = 0x2C3,
	SE_SHT_FLY_JET = 0x2C4,
	SE_SHT_FLY_ENEMY = 0x2C5,
	SE_SHT_MISSILE = 0x2C6,
	SE_SHT_ENEMYBOMB = 0x2C7,
	SE_SHT_VULCAN = 0x2C8,
	SE_SHT_EGGCARRIER = 0x2C9,
	SE_SHT_CANNON = 0x2CA,
	SE_SHT_BOSSWING = 0x2CB,
	SE_SHT_BOSSFIRE = 0x2CC,
	SE_SHT_BOSSGAO = 0x2CD,
	SE_SHT_BOSSCOLD = 0x2CE,
	SE_SHT_BOSSGAO2 = 0x2CF,
	SE_SHT_KAGU = 0x2D0,
	SE_SHT_FMINEBOMB = 0x2D1,
	SE_SHT_LOCKON = 0x2D2,
	SE_SHT_ARM = 0x2D3,
	SE_SHT_EMCOPEN = 0x2D4,
	SE_SHT_EMCSTOP = 0x2D5,
	SE_SHT_EMCCHARGE = 0x2D6,
	SE_SHT_EMCFIRE = 0x2D7,
	SE_BANK_1_SH = 0x2D8,
	SE_SH_RIDE = 0x2D9,
	SE_SH_EDGE = 0x2DA,
	SE_SH_WORM = 0x2DB,
	SE_SH_POLE = 0x2DC,
	SE_SH_POLEEND = 0x2DD,
	SE_SH_SABOTEN = 0x2DE,
	SE_SH_ROCK = 0x2DF,
	SE_SH_WORM_Q2 = 0x2E0,
	SE_BANK_2 = 0x2E1,
	SE_C_DASHER = 0x2E2,
	SE_C_IRONSPIN = 0x2E3,
	SE_C_IRONFALL = 0x2E4,
	SE_C_LEAF = 0x2E5,
	SE_C_DUMMY04 = 0x2E6,
	SE_C_GETEME = 0x2E7,
	SE_C_RBASE = 0x2E8,
	SE_C_RLAUNCH = 0x2E9,
	SE_C_RFLY = 0x2EA,
	SE_C_RBOMB = 0x2EB,
	SE_C_BURN = 0x2EC,
	SE_C_ESHOCK = 0x2ED,
	SE_C_TSUBURE = 0x2EE,
	SE_C_FALL = 0x2EF,
	SE_C_DUMMY14 = 0x2F0,
	SE_C_BUBBLE = 0x2F1,
	SE_C_BUBBLEEAT = 0x2F2,
	SE_C_GIVEo2 = 0x2F3,
	SE_C_INWATER = 0x2F4,
	SE_C_WATER = 0x2F5,
	SE_C_OUTWATER = 0x2F6,
	SE_C_WATERENV = 0x2F7,
	SE_C_TIKAL = 0x2F8,
	SE_BANK_3_SN = 0x2F9,
	SE_HORMJUMP = 0x2FA,
	SE_LDASHHOLD = 0x2FB,
	SE_LDASH = 0x2FC,
	SE_LATTACK = 0x2FD,
	SE_SONICBOOM = 0x2FE,
	SE_SPINCHARGE = 0x2FF,
	SE_SPINDASH = 0x300,
	SE_RELEASE = 0x301,
	SE_MILESFLY = 0x302,
	SE_M_ACCGATE = 0x303,
	SE_M_LIMIT = 0x304,
	SE_M_ATTACK = 0x305,
	SE_M_MULTI = 0x306,
	SE_S_WHISTLE = 0x307,
	SE_M_WHISTLE = 0x308,
	SE_METAL_JUMP = 0x307,
	SE_METAL_BRAKE = 0x308,
	SE_METAL_HOVER = 0x309,
	SE_METAL_LAND = 0x30A,
	SE_BANK_3_KN = 0x30B,
	SE_K_GLIDE = 0x30C,
	SE_K_PUNCH1 = 0x30D,
	SE_K_PUNCH2 = 0x30E,
	SE_K_PUNCH3 = 0x30F,
	SE_K_KICK = 0x310,
	SE_K_DIG = 0x311,
	SE_K_SPRING = 0x312,
	SE_K_EME = 0x313,
	SE_K_RADAR = 0x314,
	SE_K_CLIMB = 0x315,
	SE_K_TICAL = 0x316,
	SE_K_GLIDEON = 0x317,
	SE_K_CHARGE = 0x318,
	SE_K_RELEASE = 0x319,
	SE_K_WHISTLE = 0x31A,
	SE_BANK_3_AM = 0x31B,
	SE_A_GETHAMMER = 0x31C,
	SE_A_LONGHAMMER = 0x31D,
	SE_A_ROTHAMMER = 0x31E,
	SE_A_ALERT = 0x31F,
	SE_A_IO_CAN = 0x320,
	SE_A_MOVE_CAN = 0x321,
	SE_AZ_TELOP = 0x322,
	SE_AZ_GOLI = 0x323,
	SE_AZ_MARK = 0x324,
	SE_AZ_ARMSHOOT = 0x325,
	SE_AZ_DOSU1 = 0x326,
	SE_AZ_DOSU2 = 0x327,
	SE_AZ_DAMAGE1 = 0x328,
	SE_AZ_DAMAGE2 = 0x329,
	SE_AZ_CHARGE = 0x32A,
	SE_AZ_DAMAGE = 0x32B,
	SE_AZ_ENEDEST = 0x32C,
	SE_AZ_ARM = 0x32D,
	SE_AZ_EMEROT = 0x32E,
	SE_AZ_JUMP = 0x32F,
	SE_AZ_MOVE = 0x330,
	SE_AZ_LASER = 0x331,
	SE_AZ_LOCKON = 0x332,
	SE_AZ_STANDUP = 0x333,
	SE_A_WHISTLE = 0x334,
	SE_BANK_3_E2 = 0x335,
	SE_E_TALK = 0x336,
	SE_E_LIMIT = 0x337,
	SE_E_LIMIT2 = 0x338,
	SE_E_LIMIT3 = 0x339,
	SE_E_LIMIT4 = 0x33A,
	SE_E_WALK = 0x33B,
	SE_E_JUMP = 0x33C,
	SE_E_BRAKE = 0x33D,
	SE_E_LAND = 0x33E,
	SE_E_RDUSH = 0x33F,
	SE_E_RDUSH2 = 0x340,
	SE_E_HOVER = 0x341,
	SE_E_BOOSTER = 0x342,
	SE_E_BEAM = 0x343,
	SE_E_SHOT = 0x344,
	SE_E_3SHOT = 0x345,
	SE_E_SPREAD = 0x346,
	SE_E_LOCKON = 0x347,
	SE_BANK_3_BG = 0x348,
	SE_B_LAND = 0x349,
	SE_B_SWING = 0x34A,
	SE_B_CAST_OK = 0x34B,
	SE_B_CAST_X = 0x34C,
	SE_B_REEL = 0x34D,
	SE_B_FISH = 0x34E,
	SE_B_INWATER = 0x34F,
	SE_B_PUCHI = 0x350,
	SE_B_LIFESAVE = 0x351,
	SE_B_ONWATER = 0x352,
	SE_B_FBOUND = 0x353,
	SE_B_FJUMP = 0x354,
	SE_B_FGERO = 0x355,
	SE_B_BOTTOM = 0x356,
	SE_B_CAUTION = 0x357,
	SE_B_WHISTLE = 0x358,
	SE_BANK_4 = 0x359,
	SE_UNI_FIRE = 0x35A,
	SE_SPI_HYUN = 0x35B,
	SE_SPI_ELE = 0x35C,
	SE_LEO_APPR = 0x35D,
	SE_LEO_BERO = 0x35E,
	SE_PIY_PIYO = 0x35F,
	SE_PIY_APPR = 0x360,
	SE_MON_LAUG = 0x361,
	SE_MON_BOMB = 0x362,
	SE_SAI_MOVE = 0x363,
	SE_SAI_DASH = 0x364,
	SE_AME_MOVE = 0x365,
	SE_SNA_FIRE = 0x366,
	SE_SNA_WFIRE = 0x367,
	SE_ENE_DUMMY00 = 0x368,
	SE_EK_SLEEP = 0x369,
	SE_EK_AWAKEN = 0x36A,
	SE_EK_CAPTURE = 0x36B,
	SE_EK_BEAM = 0x36C,
	SE_EK_DASH = 0x36D,
	SE_EK_DOCKIN = 0x36E,
	SE_ENE_DUMMY01 = 0x36F,
	SE_ENE_DUMMY02 = 0x370,
	SE_ENE_DUMMY03 = 0x371,
	SE_SPI_HYUN_Q2 = 0x372,
	SE_BANK_4_CH = 0x373,
	SE_CH_V100 = 0x374,
	SE_CH_V101 = 0x375,
	SE_CH_V102 = 0x376,
	SE_CH_V103 = 0x377,
	SE_CH_V104 = 0x378,
	SE_CH_V105 = 0x379,
	SE_CH_V106 = 0x37A,
	SE_CH_V107 = 0x37B,
	SE_CH_V108 = 0x37C,
	SE_CH_V109 = 0x37D,
	SE_CH_V110 = 0x37E,
	SE_CH_V111 = 0x37F,
	SE_CH_V112 = 0x380,
	SE_CH_V113 = 0x381,
	SE_CH_V114 = 0x382,
	SE_CH_V115 = 0x383,
	SE_CH_V116 = 0x384,
	SE_CH_V117 = 0x385,
	SE_CH_V118 = 0x386,
	SE_CH_V119 = 0x387,
	SE_CH_V120 = 0x388,
	SE_CH_V121 = 0x389,
	SE_CH_V122 = 0x38A,
	SE_CH_V123 = 0x38B,
	SE_CH_V124 = 0x38C,
	SE_CH_V125 = 0x38D,
	SE_CH_V126 = 0x38E,
	SE_CH_V127 = 0x38F,
	SE_CH_V128 = 0x390,
	SE_CH_V129 = 0x391,
	SE_CH_V130 = 0x392,
	SE_CH_V131 = 0x393,
	SE_CH_V132 = 0x394,
	SE_CH_V133 = 0x395,
	SE_CH_V134 = 0x396,
	SE_CH_V135 = 0x397,
	SE_CH_V136 = 0x398,
	SE_CH_V137 = 0x399,
	SE_CH_V138 = 0x39A,
	SE_CH_V139 = 0x39B,
	SE_CH_V140 = 0x39C,
	SE_CH_V141 = 0x39D,
	SE_CH_V142 = 0x39E,
	SE_CH_V143 = 0x39F,
	SE_CH_V144 = 0x3A0,
	SE_CH_V145 = 0x3A1,
	SE_CH_V146 = 0x3A2,
	SE_CH_V147 = 0x3A3,
	SE_CH_V148 = 0x3A4,
	SE_CH_V149 = 0x3A5,
	SE_CH_V150 = 0x3A6,
	SE_CH_V151 = 0x3A7,
	SE_CH_V152 = 0x3A8,
	SE_CH_V153 = 0x3A9,
	SE_CH_V154 = 0x3AA,
	SE_CH_V155 = 0x3AB,
	SE_CH_V156 = 0x3AC,
	SE_CH_V157 = 0x3AD,
	SE_CH_V158 = 0x3AE,
	SE_CH_V159 = 0x3AF,
	SE_CH_V160 = 0x3B0,
	SE_BANK_5_CS = 0x3B1,
	SE_CSE_KAMOME = 0x3B2,
	SE_CSE_DUMMY00 = 0x3B3,
	SE_CSE_WAVE = 0x3B4,
	SE_CSE_DUMMY01 = 0x3B5,
	SE_CSE_WIND = 0x3B6,
	SE_BANK_5_WV = 0x3B7,
	SE_WVE_WIND1 = 0x3B8,
	SE_WVE_WIND2 = 0x3B9,
	SE_WVE_WIND3 = 0x3BA,
	SE_WVE_WIND4 = 0x3BB,
	SE_BANK_5_TP = 0x3BC,
	SE_TPE_ENV = 0x3BD,
	SE_TPE_DUMMY0 = 0x3BE,
	SE_TPE_DOKA = 0x3BF,
	SE_BANK_5_HW = 0x3C0,
	SE_HW_CITY = 0x3C1,
	SE_HW_DUMMY50 = 0x3C2,
	SE_HW_WIND = 0x3C3,
	SE_HW_DUMMY51 = 0x3C4,
	SE_BANK_5_DM = 0x3C5,
	SE_DM_WIND = 0x3C6,
	SE_DM_DUMMY50 = 0x3C7,
	SE_DM_YOGAN = 0x3C8,
	SE_DM_DUMMY51 = 0x3C9,
	SE_DM_TOPPU = 0x3CA,
	SE_DM_DUMMY52 = 0x3CB,
	SE_DM_THUNDER = 0x3CC,
	SE_DM_DUMMY53 = 0x3CD,
	SE_DM_EGGCARRIER = 0x3CE,
	SE_BANK_5_SD = 0x3CF,
	SE_SDE_SINK_ALERT = 0x3D0,
	SE_SDE_DUMMY3 = 0x3D1,
	SE_SDE_DIVE_ALERT = 0x3D2,
	SE_SDE_DUMMY2 = 0x3D3,
	SE_SDE_WIND = 0x3D4,
	SE_SDE_NOWIND = 0x3D5,
	SE_SDE_TOPPU = 0x3D6,
	SE_SDE_DUMMY1 = 0x3D7,
	SE_SDE_ENGINE = 0x3D8,
	SE_SDE_DUMMY4 = 0x3D9,
	SE_SDE_THUNDER = 0x3DA,
	SE_SDE_DUMMY5 = 0x3DB,
	SE_BANK_5_LW = 0x3DC,
	SE_LWE_INSTR = 0x3DD,
	SE_BANK_5_IC = 0x3DE,
	SE_ICE_ENV = 0x3DF,
	SE_ICE_DUMMY00 = 0x3E0,
	SE_ICE_WIND = 0x3E1,
	SE_BANK_5_CA = 0x3E2,
	SE_CAE_ENV = 0x3E3,
	SE_CAE_DUMMY00 = 0x3E4,
	SE_CAE_ENTER = 0x3E5,
	SE_BANK_5_FE = 0x3E6,
	SE_FED_FACTORY = 0x3E7,
	SE_FED_DUMMY01 = 0x3E8,
	SE_FED_GACHAPON = 0x3E9,
	SE_FED_DUMMY02 = 0x3EA,
	SE_FED_REACTOR = 0x3EB,
	SE_FED_DUMMY03 = 0x3EC,
	SE_FED_FANFAN = 0x3ED,
	SE_FED_DUMMY04 = 0x3EE,
	SE_BANK_5_HS = 0x3EF,
	SE_HSE_FACTORY = 0x3F0,
	SE_HSE_DUMMY00 = 0x3F1,
	SE_HSE_BUBBLE = 0x3F2,
	SE_HSE_DUMMY01 = 0x3F3,
	SE_HSE_ENGINE = 0x3F4,
	SE_HSE_DUMMY02 = 0x3F5,
	SE_HSE_CARGO = 0x3F6,
	SE_HSE_DUMMY03 = 0x3F7,
	SE_HSE_VSE105 = 0x3F8,
	SE_BANK_5_CZ = 0x3F9,
	SE_CZ_PATFIRE = 0x3FA,
	SE_CZ_DUMMY50 = 0x3FB,
	SE_CZ_INBODY = 0x3FC,
	SE_CZ_DUMMY51 = 0x3FD,
	SE_CZ_HELI = 0x3FE,
	SE_CZ_DUMMY52 = 0x3FF,
	SE_CZ_SILEN = 0x400,
	SE_CZ_DUMMY53 = 0x401,
	SE_CZ_RAIN = 0x402,
	SE_CZ_DUMMY54 = 0x403,
	SE_BANK_5_C6 = 0x404,
	SE_C6E_DUMMY50 = 0x405,
	SE_C6E_DUMMY51 = 0x406,
	SE_C6E_INBODY = 0x407,
	SE_C6E_DUMMY52 = 0x408,
	SE_C6E_DUMMY53 = 0x409,
	SE_C6E_DUMMY54 = 0x40A,
	SE_C6E_DUMMY55 = 0x40B,
	SE_C6E_DUMMY56 = 0x40C,
	SE_C6E_DUMMY57 = 0x40D,
	SE_C6E_WIND = 0x40E,
	SE_C6E_DUMMY58 = 0x40F,
	SE_C6E_EGGCARRIER = 0x410,
	SE_C6E_DUMMY59 = 0x411,
	SE_C6E_THUNDER = 0x412,
	SE_C6E_DUMMY5A = 0x413,
	SE_C6_SATEMOVE = 0x414,
	SE_C6_TRANSFORM = 0x415,
	SE_BANK_5_PC = 0x416,
	SE_PCE_INBODY = 0x417,
	SE_PCE_DUMMY00 = 0x418,
	SE_PCE_CORE = 0x419,
	SE_PCE_DUMMY01 = 0x41A,
	SE_PCE_BARRIER = 0x41B,
	SE_PCE_DUMMY02 = 0x41C,
	SE_PCE_PCINBODY = 0x41D,
	SE_PCE_DUMMY03 = 0x41E,
	SE_PC_SS_ONWATER = 0x41F,
	SE_PC_SS_ONWATER2 = 0x420,
	SE_PC_SS_FIELD = 0x421,
	SE_BANK_5_ER = 0x422,
	SE_ERE_ALERT = 0x423,
	SE_ERE_WIND = 0x424,
	SE_ERE_ENGINE1 = 0x425,
	SE_ERE_ENGINE2 = 0x426,
	SE_ERE_THUNDER = 0x427,
	SE_ERE_WAVE = 0x428,
	SE_ERE_E_LEAK = 0x429,
	SE_BANK_5_SS = 0x42A,
	SE_SSE_CASINO = 0x42B,
	SE_SSE_DUMMY00 = 0x42C,
	SE_SSE_ENTRANCE = 0x42D,
	SE_SSE_DUMMY01 = 0x42E,
	SE_SSE_BEACH = 0x42F,
	SE_SSE_DUMMY02 = 0x430,
	SE_SSE_DUMMY03 = 0x431,
	SE_SSE_DUMMY04 = 0x432,
	SE_SSE_STREET = 0x433,
	SE_SSE_DUMMY05 = 0x434,
	SE_SSE_EGGCARRIER = 0x435,
	SE_BANK_5_EC = 0x436,
	SE_ECE_ALERT = 0x437,
	SE_ECE_WIND = 0x438,
	SE_ECE_ENG_OUT = 0x439,
	SE_ECE_ENG_IN = 0x43A,
	SE_ECE_THUNDER = 0x43B,
	SE_ECE_WAVE = 0x43C,
	SE_ECE_ZERO = 0x43D,
	SE_ECE_DUMMY00 = 0x43E,
	SE_ECE_DUMMY01 = 0x43F,
	SE_ECE_DUMMY02 = 0x440,
	SE_ECE_DUMMY03 = 0x441,
	SE_ECE_DUMMY04 = 0x442,
	SE_ECE_DUMMY05 = 0x443,
	SE_ECE_DUMMY06 = 0x444,
	SE_ECE_DUMMY07 = 0x445,
	SE_ECE_DUMMY08 = 0x446,
	SE_EC_HITSONICTAILS = 0x447,
	SE_EC_WARPHOLE = 0x448,
	SE_EC_RAFT = 0x449,
	SE_EC_BOAT = 0x44A,
	SE_BANK_5_MR = 0x44B,
	SE_MRE_EGGBASE = 0x44C,
	SE_MRE_DUMMY00 = 0x44D,
	SE_MRE_JUNGLE_DAY = 0x44E,
	SE_MRE_DUMMY01 = 0x44F,
	SE_MRE_JUNGLE_NIGHT = 0x450,
	SE_MRE_DUMMY02 = 0x451,
	SE_MRE_WIND = 0x452,
	SE_MRE_DUMMY03 = 0x453,
	SE_MRE_OCEAN = 0x454,
	SE_MRE_DUMMY04 = 0x455,
	SE_MRE_WATER = 0x456,
	SE_MRE_DUMMY05 = 0x457,
	SE_MRE_FIRE = 0x458,
	SE_MRE_DUMMY06 = 0x459,
	SE_MRE_GOGOGO = 0x45A,
	SE_BANK_5_CH = 0x45B,
	SE_CH_V0 = 0x45C,
	SE_CH_V1 = 0x45D,
	SE_CH_V2 = 0x45E,
	SE_CH_V3 = 0x45F,
	SE_CH_V4 = 0x460,
	SE_CH_V5 = 0x461,
	SE_CH_V6 = 0x462,
	SE_CH_V7 = 0x463,
	SE_CH_V8 = 0x464,
	SE_CH_V9 = 0x465,
	SE_CH_V10 = 0x466,
	SE_CH_V11 = 0x467,
	SE_CH_V12 = 0x468,
	SE_CH_V13 = 0x469,
	SE_CH_V14 = 0x46A,
	SE_CH_V15 = 0x46B,
	SE_CH_V16 = 0x46C,
	SE_CH_V17 = 0x46D,
	SE_CH_V18 = 0x46E,
	SE_CH_V19 = 0x46F,
	SE_CH_V20 = 0x470,
	SE_CH_V21 = 0x471,
	SE_CH_V22 = 0x472,
	SE_CH_V23 = 0x473,
	SE_CH_V24 = 0x474,
	SE_CH_V25 = 0x475,
	SE_CH_V26 = 0x476,
	SE_CH_V27 = 0x477,
	SE_CH_V28 = 0x478,
	SE_CH_V29 = 0x479,
	SE_CH_V30 = 0x47A,
	SE_CH_V31 = 0x47B,
	SE_CH_V32 = 0x47C,
	SE_CH_V33 = 0x47D,
	SE_CH_V34 = 0x47E,
	SE_CH_V35 = 0x47F,
	SE_CH_V36 = 0x480,
	SE_CH_V37 = 0x481,
	SE_CH_V38 = 0x482,
	SE_CH_V39 = 0x483,
	SE_CH_V40 = 0x484,
	SE_CH_V41 = 0x485,
	SE_CH_V42 = 0x486,
	SE_CH_V43 = 0x487,
	SE_CH_V44 = 0x488,
	SE_CH_V45 = 0x489,
	SE_CH_V46 = 0x48A,
	SE_CH_V47 = 0x48B,
	SE_CH_V48 = 0x48C,
	SE_CH_V49 = 0x48D,
	SE_CH_V50 = 0x48E,
	SE_CH_V51 = 0x48F,
	SE_CH_V52 = 0x490,
	SE_CH_V53 = 0x491,
	SE_CH_V54 = 0x492,
	SE_CH_V55 = 0x493,
	SE_CH_V56 = 0x494,
	SE_CH_V57 = 0x495,
	SE_CH_V58 = 0x496,
	SE_CH_V59 = 0x497,
	SE_CH_V60 = 0x498,
	SE_CH_V61 = 0x499,
	SE_CH_V62 = 0x49A,
	SE_CH_V63 = 0x49B,
	SE_CH_V64 = 0x49C,
	SE_CH_V65 = 0x49D,
	SE_CH_V66 = 0x49E,
	SE_CH_V67 = 0x49F,
	SE_CH_V68 = 0x4A0,
	SE_CH_V69 = 0x4A1,
	SE_CH_V70 = 0x4A2,
	SE_CH_V71 = 0x4A3,
	SE_CH_V72 = 0x4A4,
	SE_CH_V73 = 0x4A5,
	SE_CH_V74 = 0x4A6,
	SE_CH_V75 = 0x4A7,
	SE_CH_V76 = 0x4A8,
	SE_CH_V77 = 0x4A9,
	SE_CH_V78 = 0x4AA,
	SE_CH_V79 = 0x4AB,
	SE_CH_V80 = 0x4AC,
	SE_CH_V81 = 0x4AD,
	SE_CH_V82 = 0x4AE,
	SE_CH_V83 = 0x4AF,
	SE_CH_V84 = 0x4B0,
	SE_CH_V85 = 0x4B1,
	SE_CH_V86 = 0x4B2,
	SE_CH_V87 = 0x4B3,
	SE_CH_V88 = 0x4B4,
	SE_CH_V89 = 0x4B5,
	SE_CH_V90 = 0x4B6,
	SE_CH_V91 = 0x4B7,
	SE_CH_V92 = 0x4B8,
	SE_CH_V93 = 0x4B9,
	SE_CH_V94 = 0x4BA,
	SE_CH_V95 = 0x4BB,
	SE_CH_V96 = 0x4BC,
	SE_CH_V97 = 0x4BD,
	SE_CH_V98 = 0x4BE,
	SE_CH_V99 = 0x4BF,
	SE_BANK_5_SH = 0x4C0,
	SE_SHE_WIND1 = 0x4C1,
	SE_SHE_WIND2 = 0x4C2,
	SE_SHE_WIND3 = 0x4C3,
	SE_SHE_WIND4 = 0x4C4,
	SE_BANK_6_SV = 0x4C5,
	SE_SV_WALLHIT = 0x4C6,
	SE_SV_YABA = 0x4C7,
	SE_SV_WAIT = 0x4C8,
	SE_SV_THROW = 0x4C9,
	SE_SV_PUSH = 0x4CA,
	SE_SV_CHARGED = 0x4CB,
	SE_SV_LDASH = 0x4CC,
	SE_SV_ITEMGET0 = 0x4CD,
	SE_SV_ITEMGET1 = 0x4CE,
	SE_SV_LADDER = 0x4CF,
	SE_SV_OH = 0x4D0,
	SE_SV_DAMAGE = 0x4D1,
	SE_SV_FDAMAGE = 0x4D2,
	SE_SV_EDAMAGE = 0x4D3,
	SE_SV_JUMP1 = 0x4D4,
	SE_SV_JUMP2 = 0x4D5,
	SE_MV_WALLHIT = 0x4D6,
	SE_MV_YABA = 0x4D7,
	SE_MV_WAIT = 0x4D8,
	SE_MV_THROW = 0x4D9,
	SE_MV_PUSH = 0x4DA,
	SE_MV_ATTACK1 = 0x4DB,
	SE_MV_ATTACK2 = 0x4DC,
	SE_MV_ATTACK3 = 0x4DD,
	SE_MV_ITEMGET0 = 0x4DE,
	SE_MV_ITEMGET1 = 0x4DF,
	SE_MV_LADDER = 0x4E0,
	SE_MV_DAMAGE = 0x4E1,
	SE_MV_FDAMAGE = 0x4E2,
	SE_MV_EDAMAGE = 0x4E3,
	SE_MV_JUMP1 = 0x4E4,
	SE_MV_JUMP2 = 0x4E5,
	SE_BANK_6_KV = 0x4E6,
	SE_KV_WALLHIT = 0x4E7,
	SE_KV_YABA = 0x4E8,
	SE_KV_WAIT = 0x4E9,
	SE_KV_THROW = 0x4EA,
	SE_KV_PUSH = 0x4EB,
	SE_KV_DIG = 0x4EC,
	SE_KV_DAME = 0x4ED,
	SE_KV_HAZURE = 0x4EE,
	SE_KV_CYOTTO = 0x4EF,
	SE_KV_LUCKY = 0x4F0,
	SE_KV_PUNCH3 = 0x4F1,
	SE_KV_PUNCH4 = 0x4F2,
	SE_KV_PUNCH5 = 0x4F3,
	SE_KV_KAKERA1 = 0x4F4,
	SE_KV_KAKERA2 = 0x4F5,
	SE_KV_ITEMGET0 = 0x4F6,
	SE_KV_LADDER = 0x4F7,
	SE_KV_OH = 0x4F8,
	SE_KV_DAMAGE = 0x4F9,
	SE_KV_FDAMAGE = 0x4FA,
	SE_KV_EDAMAGE = 0x4FB,
	SE_KV_JUMP1 = 0x4FC,
	SE_KV_JUMP2 = 0x4FD,
	SE_BANK_6_AV = 0x4FE,
	SE_AV_JUMP1 = 0x4FF,
	SE_AV_JUMP2 = 0x500,
	SE_AV_WALLHIT = 0x501,
	SE_AV_YABA = 0x502,
	SE_AV_WAIT = 0x503,
	SE_AV_DUMMY0 = 0x504,
	SE_AV_THROW = 0x505,
	SE_AV_PUSH = 0x506,
	SE_AV_DUMMY1 = 0x507,
	SE_AV_ATTACK = 0x508,
	SE_AV_H_JUMP = 0x509,
	SE_AV_FURA = 0x50A,
	SE_AV_ITEMGET1 = 0x50B,
	SE_AV_ITEMGET2 = 0x50C,
	SE_AV_LADDER = 0x50D,
	SE_AV_OH = 0x50E,
	SE_AV_DAMAGE = 0x50F,
	SE_BANK_6_EV = 0x510,
	SE_EV_DUMMY0 = 0x511,
	SE_EV_DUMMY1 = 0x512,
	SE_EV_PICK = 0x513,
	SE_EV_PUT = 0x514,
	SE_EV_THROW = 0x515,
	SE_EV_PUSH = 0x516,
	SE_EV_PULL = 0x517,
	SE_EV_TRANSFORM = 0x518,
	SE_EV_LIMIT = 0x519,
	SE_EV_ITEM1 = 0x51A,
	SE_EV_ITEM2 = 0x51B,
	SE_EV_DUMMY2 = 0x51C,
	SE_BANK_6_BV = 0x51D,
	SE_BV_JUMP1 = 0x51E,
	SE_BV_JUMP2 = 0x51F,
	SE_BV_WALLHIT = 0x520,
	SE_BV_YABA = 0x521,
	SE_BV_WAIT = 0x522,
	SE_BV_DUMMY0 = 0x523,
	SE_BV_THROW = 0x524,
	SE_BV_PUSH = 0x525,
	SE_BV_CAST = 0x526,
	SE_BV_DOWN = 0x527,
	SE_BV_LADDER = 0x528,
	SE_BV_OH = 0x529,
	SE_BV_DAMAGE = 0x52A,
	SE_BV_DUMMY1 = 0x52B,
	SE_BANK_6_EVENT = 0x52C,
	SE_EVENT_00 = 0x52D,
	SE_EVENT_01 = 0x52E,
	SE_EVENT_02 = 0x52F,
	SE_EVENT_03 = 0x530,
	SE_EVENT_04 = 0x531,
	SE_EVENT_05 = 0x532,
	SE_EVENT_06 = 0x533,
	SE_EVENT_07 = 0x534,
	SE_EVENT_08 = 0x535,
	SE_EVENT_09 = 0x536,
	SE_EVENT_10 = 0x537,
	SE_EVENT_11 = 0x538,
	SE_EVENT_12 = 0x539,
	SE_EVENT_13 = 0x53A,
	SE_EVENT_14 = 0x53B,
	SE_EVENT_15 = 0x53C,
	SE_EVENT_16 = 0x53D,
	SE_EVENT_17 = 0x53E,
	SE_EVENT_18 = 0x53F,
	SE_EVENT_19 = 0x540,
	SE_EVENT_20 = 0x541,
	SE_EVENT_21 = 0x542,
	SE_EVENT_22 = 0x543,
	SE_EVENT_23 = 0x544,
	SE_EVENT_24 = 0x545,
	SE_EVENT_25 = 0x546,
	SE_EVENT_26 = 0x547,
	SE_EVENT_27 = 0x548,
	SE_EVENT_28 = 0x549,
	SE_EVENT_29 = 0x54A,
	SE_EVENT_30 = 0x54B,
	SE_EVENT_31 = 0x54C,
	SE_EVENT_32 = 0x54D,
	SE_EVENT_33 = 0x54E,
	SE_EVENT_34 = 0x54F,
	SE_EVENT_35 = 0x550,
	SE_EVENT_36 = 0x551,
	SE_EVENT_37 = 0x552,
	SE_EVENT_38 = 0x553,
	SE_EVENT_39 = 0x554,
	SE_EVENT_40 = 0x555,
	SE_EVENT_41 = 0x556,
	SE_EVENT_42 = 0x557,
	SE_EVENT_43 = 0x558,
	SE_EVENT_44 = 0x559,
	SE_EVENT_45 = 0x55A,
	SE_EVENT_46 = 0x55B,
	SE_EVENT_47 = 0x55C,
	SE_BANK_7_CH = 0x55D,
	SE_CH_JINGLE0 = 0x55E,
	SE_CH_JINGLE1 = 0x55F,
	SE_CH_JINGLE2 = 0x560,
	SE_CH_JINGLE3 = 0x561,
	SE_CH_JINGLE4 = 0x562,
	SE_CH_JINGLE5 = 0x563,
	SE_CH_JINGLE6 = 0x564,
	SE_CH_JINGLE7 = 0x565,
	SE_BANK_8_DL = 0x566,
	SE_DL_DOWNLOAD = 0x567,
	SE_BANK_ADX = 0x568,
	SE_AV_ADVERTIZE = 0x569,
	SE_AV_CARTGOAL = 0x56A,
	SE_AV_CARTJUMP = 0x56B,
	SE_AV_CLEAR = 0x56C,
	SE_AV_CLEARBAD = 0x56D,
	SE_AV_CLEARBOSS = 0x56E,
	SE_AV_CLEARGOOD = 0x56F,
	SE_AV_CLEARBEST = 0x570,
	SE_AV_DAMAGECAPTURED = 0x571,
	SE_AV_EDAMAGE = 0x572,
	SE_AV_DEAD = 0x573,
	SE_AV_FALLDEAD = 0x574,
	SE_AV_NOAIRDEAD = 0x575,
	SE_AV_TAIHOU0 = 0x576,
	SE_BV_ADVERTIZE = 0x577,
	SE_BV_BIGFISH = 0x578,
	SE_BV_CARTGOAL = 0x579,
	SE_BV_CLEAR = 0x57A,
	SE_BV_CLEARBAD = 0x57B,
	SE_BV_CLEARBEST = 0x57C,
	SE_BV_CLEARBOSS = 0x57D,
	SE_BV_CLEARGOOD = 0x57E,
	SE_BV_CUT1 = 0x57F,
	SE_BV_CUT2 = 0x580,
	SE_BV_DAMAGECAPTURED = 0x581,
	SE_BV_DEAD = 0x582,
	SE_BV_DONTFISH = 0x583,
	SE_BV_FALLDEAD = 0x584,
	SE_BV_FISHUP = 0x585,
	SE_BV_HIT = 0x586,
	SE_BV_ITEMGET0 = 0x587,
	SE_BV_MIDDLEFISH = 0x588,
	SE_BV_NOAIRDEAD = 0x589,
	SE_BV_SMALLFISH = 0x58A,
	SE_BV_TAIHOU0 = 0x58B,
	SE_BV_WHATISTHIS = 0x58C,
	SE_BV_YAHOO = 0x58D,
	SE_EV_ADVERTIZE = 0x58E,
	SE_EV_CARTGOAL = 0x58F,
	SE_EV_CARTJUMP = 0x590,
	SE_EV_CLEAR = 0x591,
	SE_EV_CLEAR_E101 = 0x592,
	SE_EV_CLEAR_EME = 0x593,
	SE_EV_CLEAR_HOT = 0x594,
	SE_EV_CLEAR_MT = 0x595,
	SE_EV_CLEAR_WIND = 0x596,
	SE_EV_DAMAGE = 0x597,
	SE_EV_DAMAGECAPTURED = 0x598,
	SE_EV_DEAD = 0x599,
	SE_EV_FACEACT0 = 0x59A,
	SE_EV_FACEACT1 = 0x59B,
	SE_EV_FACEACT2 = 0x59C,
	SE_EV_FACEACT3 = 0x59D,
	SE_EV_READY0 = 0x59E,
	SE_EV_READY1 = 0x59F,
	SE_EV_SURPRISE = 0x5A0,
	SE_EV_TIMEUP = 0x5A1,
	SE_KV_ADVERTIZE = 0x5A2,
	SE_KV_CARTGOAL = 0x5A3,
	SE_KV_CARTJUMP = 0x5A4,
	SE_KV_CLEAR = 0x5A5,
	SE_KV_CLEARBAD = 0x5A6,
	SE_KV_CLEARBEST = 0x5A7,
	SE_KV_CLEARBOSS = 0x5A8,
	SE_KV_CLEARGOOD = 0x5A9,
	SE_KV_DAMAGECAPTURED = 0x5AA,
	SE_KV_DEAD = 0x5AB,
	SE_KV_NOAIRDEAD = 0x5AC,
	SE_KV_FALLDEAD = 0x5AD,
	SE_KV_TAIHOU0 = 0x5AE,
	SE_MV_ADVERTIZE = 0x5AF,
	SE_MV_CARTGOAL = 0x5B0,
	SE_MV_CARTJUMP = 0x5B1,
	SE_MV_CLEAR = 0x5B2,
	SE_MV_CLEARBAD = 0x5B3,
	SE_MV_CLEARBEST = 0x5B4,
	SE_MV_CLEARBOSS = 0x5B5,
	SE_MV_CLEARGOOD = 0x5B6,
	SE_MV_DAMAGECAPTURED = 0x5B7,
	SE_MV_DEAD = 0x5B8,
	SE_MV_FALLDEAD = 0x5B9,
	SE_MV_XXITEMGET0 = 0x5BA,
	SE_MV_XXITEMGET1 = 0x5BB,
	SE_MV_NOAIRDEAD = 0x5BC,
	SE_MV_OH = 0x5BD,
	SE_MV_SNOW_1 = 0x5BE,
	SE_MV_SNOW_2 = 0x5BF,
	SE_MV_SNOW_3 = 0x5C0,
	SE_MV_TAIHOU0 = 0x5C1,
	SE_MV_TAIHOU1 = 0x5C2,
	SE_MV_TIRED = 0x5C3,
	SE_MV_TIRELIMIT = 0x5C4,
	SE_MV_TIRELIMIT1 = 0x5C5,
	SE_SV_ADRIB00 = 0x5C6,
	SE_SV_ADRIB01 = 0x5C7,
	SE_SV_ADRIB02 = 0x5C8,
	SE_SV_ADRIB03 = 0x5C9,
	SE_SV_ADRIB04 = 0x5CA,
	SE_SV_ADRIB05 = 0x5CB,
	SE_SV_ADRIB06 = 0x5CC,
	SE_SV_ADRIB07 = 0x5CD,
	SE_SV_ADRIB08 = 0x5CE,
	SE_SV_ADRIB09 = 0x5CF,
	SE_SV_ADRIB10 = 0x5D0,
	SE_SV_ADRIB11 = 0x5D1,
	SE_SV_ADRIB12 = 0x5D2,
	SE_SV_ADRIB13 = 0x5D3,
	SE_SV_ADVERTIZE = 0x5D4,
	SE_SV_CARTGOAL = 0x5D5,
	SE_SV_CARTJUMP = 0x5D6,
	SE_SV_CLEAR = 0x5D7,
	SE_SV_CLEARBAD = 0x5D8,
	SE_SV_CLEARBEST = 0x5D9,
	SE_SV_CLEARBOSS = 0x5DA,
	SE_SV_CLEARGOOD = 0x5DB,
	SE_SV_DAMAGECAPTURED = 0x5DC,
	SE_SV_XXDAMAGEFLAME1 = 0x5DD,
	SE_SV_DEAD = 0x5DE,
	SE_SV_FALLDEAD = 0x5DF,
	SE_SV_XXITEMGET0 = 0x5E0,
	SE_SV_XXITEMGET1 = 0x5E1,
	SE_SV_NOAIRDEAD = 0x5E2,
	SE_SV_SNOW_3 = 0x5E3,
	SE_SV_SNOW_4 = 0x5E4,
	SE_SV_TAIHOU0 = 0x5E5,
	SE_SV_TAIHOU1 = 0x5E6,
	SE_ELEV = 0x5E7,
	SE_SBRIDGE_GISHI = 0x5E8,
	SE_E_SAIJET = 0x5E9,
	SE_E_SAISTART = 0x5EA,
	SE_HEBIBOOST = 0x5EB,
	SE_NUMBER = 0x5EC,
};

enum eCHAO_STAGE_NUMBER
{
	CHAO_STG_NONE = 0x0,
	CHAO_STG_RACE = 0x1,
	CHAO_STG_ENTRANCE = 0x2,
	CHAO_STG_ODEKAKE = 0x3,
	CHAO_STG_SS = 0x4,
	CHAO_STG_EC = 0x5,
	CHAO_STG_MR = 0x6,
	CHAO_STG_BLACKMARKET = 0x7,
	CHAO_STG_QUIT = 0x8,
};

enum LOOK_MODE
{
	LOOK_MODE_NORMAL = 0x0,
	LOOK_MODE_ANGLE = 0x1,
	LOOK_MODE_POINT = 0x2,
	LOOK_MODE_OBJECT = 0x3,
};

enum MD_SONIC
{
	MD_SONIC_INIT = 0x0,
	MD_SONIC_STND = 0x1,
	MD_SONIC_WALK = 0x2,
	MD_SONIC_1DWK = 0x3,
	MD_SONIC_SPIN = 0x4,
	MD_SONIC_SPDS = 0x5,
	MD_SONIC_LSDS = 0x6,
	MD_SONIC_1DSP = 0x7,
	MD_SONIC_JUMP = 0x8,
	MD_SONIC_SPRG = 0x9,
	MD_SONIC_LNCH = 0xA,
	MD_SONIC_PARA = 0xB,
	MD_SONIC_FALL = 0xC,
	MD_SONIC_STOP = 0xD,
	MD_SONIC_SPAT = 0xE,
	MD_SONIC_PUSH = 0xF,
	MD_SONIC_DAMG = 0x10,
	MD_SONIC_BACK = 0x11,
	MD_SONIC_CRSH = 0x12,
	MD_SONIC_SLID = 0x13,
	MD_SONIC_PLON = 0x14,
	MD_SONIC_PICK = 0x15,
	MD_SONIC_PUT_ = 0x16,
	MD_SONIC_HOLD = 0x17,
	MD_SONIC_TOCH = 0x18,
	MD_SONIC_HWLK = 0x19,
	MD_SONIC_THRW = 0x1A,
	MD_SONIC_HSTP = 0x1B,
	MD_SONIC_HFLL = 0x1C,
	MD_SONIC_HJMP = 0x1D,
	MD_SONIC_HSPR = 0x1E,
	MD_SONIC_HLNC = 0x1F,
	MD_SONIC_PULL = 0x20,
	MD_SONIC_THRU = 0x21,
	MD_SONIC_SHAK = 0x22,
	MD_SONIC_ESHK = 0x23,
	MD_SONIC_HGWT = 0x24,
	MD_SONIC_HGGO = 0x25,
	MD_SONIC_LDWT = 0x26,
	MD_SONIC_LDGO = 0x27,
	MD_SONIC_PNJP = 0x28,
	MD_SONIC_PNWT = 0x29,
	MD_SONIC_CAPT = 0x2A,
	MD_SONIC_ICED = 0x2B,
	MD_SONIC_LSA_ = 0x2C,
	MD_SONIC_S3A2_CART = 0x2D,
	MD_SONIC_S4A2_WALK = 0x2E,
	MD_SONIC_S4A2_SPDS = 0x2F,
	MD_SONIC_S4A2_FALL = 0x30,
	MD_SONIC_S4A2_JUMP = 0x31,
	MD_SONIC_S4A2_CRSH = 0x32,
	MD_SONIC_S6A1_WAIT = 0x33,
	MD_SONIC_S6A1_SLID = 0x34,
	MD_SONIC_S6A1_LROT = 0x35,
	MD_SONIC_S6A1_RROT = 0x36,
	MD_SONIC_S8A2_WAIT = 0x37,
	MD_SONIC_S8A2_SLIP = 0x38,
	MD_SONIC_S8A2_LROT = 0x39,
	MD_SONIC_S8A2_RROT = 0x3A,
	MD_SONIC_S8A2_JUMP = 0x3B,
	MD_SONIC_S8A2_CLMB = 0x3C,
	MD_SONIC_S8A2_FLY_ = 0x3D,
	MD_SONIC_S8A3_SLID = 0x3E,
	MD_SONIC_S8A3_FSLD = 0x3F,
	MD_SONIC_S8A3_BRAK = 0x40,
	MD_SONIC_S8A3_FALL = 0x41,
	MD_SONIC_S8A3_JUMP = 0x42,
	MD_SONIC_S8A3_SPEC = 0x43,
	MD_SONIC_S8A3_CRSH = 0x44,
	MD_SONIC_S9A1_PINB = 0x45,
	MD_SONIC_S9A1_PINF = 0x46,
	MD_SONIC_CNADE_START = 0x47,
	MD_SONIC_CNADE_LOOP = 0x48,
	MD_SONIC_CNADE_END = 0x49,
	MD_SONIC_CFUE = 0x4A,
	MD_SUPER_STND = 0x4B,
	MD_SUPER_WALK = 0x4C,
	MD_SUPER_1DWK = 0x4D,
	MD_SUPER_FALL = 0x4E,
	MD_SUPER_LNCH = 0x4F,
	MD_SUPER_SPRG = 0x50,
	MD_SUPER_SPAT = 0x51,
	MD_SUPER_JUMP = 0x52,
	MD_SONIC_POSE = 0x53,
	MD_SONIC_EVENT = 0x54,
	MD_SONIC_DOZA = 0x55,
	MD_SONIC_KILL = 0x56,
	MD_SONIC_EDIT = 0x57,
};

enum MD_MILES
{
	MD_MILES_INIT = 0x0,
	MD_MILES_STND = 0x1,
	MD_MILES_WALK = 0x2,
	MD_MILES_1DWK = 0x3,
	MD_MILES_ROLL = 0x4,
	MD_MILES_1DSP = 0x5,
	MD_MILES_JUMP = 0x6,
	MD_MILES_SPRG = 0x7,
	MD_MILES_LNCH = 0x8,
	MD_MILES_PARA = 0x9,
	MD_MILES_FALL = 0xA,
	MD_MILES_STOP = 0xB,
	MD_MILES_PUSH = 0xC,
	MD_MILES_DAMG = 0xD,
	MD_MILES_BACK = 0xE,
	MD_MILES_FLY_ = 0xF,
	MD_MILES_CRSH = 0x10,
	MD_MILES_SLID = 0x11,
	MD_MILES_PLON = 0x12,
	MD_MILES_TIRE = 0x13,
	MD_MILES_TATK = 0x14,
	MD_MILES_PICK = 0x15,
	MD_MILES_PUT_ = 0x16,
	MD_MILES_HOLD = 0x17,
	MD_MILES_TOCH = 0x18,
	MD_MILES_HWLK = 0x19,
	MD_MILES_THRW = 0x1A,
	MD_MILES_HSTP = 0x1B,
	MD_MILES_HFLL = 0x1C,
	MD_MILES_HJMP = 0x1D,
	MD_MILES_HSPR = 0x1E,
	MD_MILES_HLNC = 0x1F,
	MD_MILES_PULL = 0x20,
	MD_MILES_THRU = 0x21,
	MD_MILES_SHAK = 0x22,
	MD_MILES_ESHK = 0x23,
	MD_MILES_HGWT = 0x24,
	MD_MILES_HGGO = 0x25,
	MD_MILES_LDWT = 0x26,
	MD_MILES_LDGO = 0x27,
	MD_MILES_PNJP = 0x28,
	MD_MILES_PNWT = 0x29,
	MD_MILES_CAPT = 0x2A,
	MD_MILES_S3A2_CART = 0x2B,
	MD_MILES_S6A1_WAIT = 0x2C,
	MD_MILES_S6A1_SLID = 0x2D,
	MD_MILES_S6A1_LROT = 0x2E,
	MD_MILES_S6A1_RROT = 0x2F,
	MD_MILES_S8A3_SLID = 0x30,
	MD_MILES_S8A3_FSLD = 0x31,
	MD_MILES_S8A3_BRAK = 0x32,
	MD_MILES_S8A3_FALL = 0x33,
	MD_MILES_S8A3_JUMP = 0x34,
	MD_MILES_S8A3_SPEC = 0x35,
	MD_MILES_S8A3_CRSH = 0x36,
	MD_MILES_S9A1_PINB = 0x37,
	MD_MILES_S9A1_PINF = 0x38,
	MD_MILES_POSE = 0x39,
	MD_MILES_EVENT = 0x3A,
	MD_MILES_DOZA = 0x3B,
	MD_MILES_KILL = 0x3C,
	MD_MILES_PROP = 0x3D,
	MD_MILES_KIME = 0x3E,
	MD_MILES_CNADE_START = 0x3F,
	MD_MILES_CNADE_LOOP = 0x40,
	MD_MILES_CNADE_END = 0x41,
	MD_MILES_CFUE = 0x42,
	MD_MILES_EDIT = 0x43,
};

enum MD_KNUCK
{
	MD_KNUCK_INIT = 0x0,
	MD_KNUCK_STND = 0x1,
	MD_KNUCK_WALK = 0x2,
	MD_KNUCK_1DWK = 0x3,
	MD_KNUCK_ROLL = 0x4,
	MD_KNUCK_1DSP = 0x5,
	MD_KNUCK_JUMP = 0x6,
	MD_KNUCK_SPRG = 0x7,
	MD_KNUCK_LNCH = 0x8,
	MD_KNUCK_FALL = 0x9,
	MD_KNUCK_STOP = 0xA,
	MD_KNUCK_GLID = 0xB,
	MD_KNUCK_GTRN = 0xC,
	MD_KNUCK_PUSH = 0xD,
	MD_KNUCK_DAMG = 0xE,
	MD_KNUCK_BACK = 0xF,
	MD_KNUCK_PLON = 0x10,
	MD_KNUCK_CRSH = 0x11,
	MD_KNUCK_HMG0 = 0x12,
	MD_KNUCK_DIGD = 0x13,
	MD_KNUCK_DIGU = 0x14,
	MD_KNUCK_DIGT = 0x15,
	MD_KNUCK_DGX0 = 0x16,
	MD_KNUCK_DGX1 = 0x17,
	MD_KNUCK_CLIM = 0x18,
	MD_KNUCK_CLIU = 0x19,
	MD_KNUCK_PUNC = 0x1A,
	MD_KNUCK_PICK = 0x1B,
	MD_KNUCK_PUT_ = 0x1C,
	MD_KNUCK_HOLD = 0x1D,
	MD_KNUCK_TOCH = 0x1E,
	MD_KNUCK_HWLK = 0x1F,
	MD_KNUCK_THRW = 0x20,
	MD_KNUCK_HSTP = 0x21,
	MD_KNUCK_HFLL = 0x22,
	MD_KNUCK_HJMP = 0x23,
	MD_KNUCK_HSPR = 0x24,
	MD_KNUCK_HLNC = 0x25,
	MD_KNUCK_PULL = 0x26,
	MD_KNUCK_THRU = 0x27,
	MD_KNUCK_SHAK = 0x28,
	MD_KNUCK_ESHK = 0x29,
	MD_KNUCK_HGWT = 0x2A,
	MD_KNUCK_HGGO = 0x2B,
	MD_KNUCK_LDWT = 0x2C,
	MD_KNUCK_LDGO = 0x2D,
	MD_KNUCK_PNJP = 0x2E,
	MD_KNUCK_PNWT = 0x2F,
	MD_KNUCK_ICED = 0x30,
	MD_KNUCK_EVENT = 0x31,
	MD_KNUCK_DOZA = 0x32,
	MD_KNUCK_KILL = 0x33,
	MD_KNUCK_S3A2_CART = 0x34,
	MD_KNUCK_CNADE_START = 0x35,
	MD_KNUCK_CNADE_LOOP = 0x36,
	MD_KNUCK_CNADE_END = 0x37,
	MD_KNUCK_CFUE = 0x38,
	MD_KNUCK_EDIT = 0x39,
};

enum MD_AMY
{
	MD_AMY_INIT = 0x0,
	MD_AMY_STND = 0x1,
	MD_AMY_WALK = 0x2,
	MD_AMY_1DWK = 0x3,
	MD_AMY_1DSP = 0x4,
	MD_AMY_JUMP = 0x5,
	MD_AMY_SPRG = 0x6,
	MD_AMY_LNCH = 0x7,
	MD_AMY_FALL = 0x8,
	MD_AMY_STOP = 0x9,
	MD_AMY_PUSH = 0xA,
	MD_AMY_DAMG = 0xB,
	MD_AMY_BACK = 0xC,
	MD_AMY_PLON = 0xD,
	MD_AMY_CRSH = 0xE,
	MD_AMY_HNDL = 0xF,
	MD_AMY_BLNC = 0x10,
	MD_AMY_DRTK = 0x11,
	MD_AMY_DROF = 0x12,
	MD_AMY_HAT_ = 0x13,
	MD_AMY_RHM_ = 0x14,
	MD_AMY_HMJ_ = 0x15,
	MD_AMY_FHM_ = 0x16,
	MD_AMY_PICK = 0x17,
	MD_AMY_PUT_ = 0x18,
	MD_AMY_HOLD = 0x19,
	MD_AMY_TOCH = 0x1A,
	MD_AMY_HWLK = 0x1B,
	MD_AMY_THRW = 0x1C,
	MD_AMY_HSTP = 0x1D,
	MD_AMY_HFLL = 0x1E,
	MD_AMY_HJMP = 0x1F,
	MD_AMY_HSPR = 0x20,
	MD_AMY_HLNC = 0x21,
	MD_AMY_PULL = 0x22,
	MD_AMY_THRU = 0x23,
	MD_AMY_SHAK = 0x24,
	MD_AMY_ESHK = 0x25,
	MD_AMY_HGWT = 0x26,
	MD_AMY_HGGO = 0x27,
	MD_AMY_LDWT = 0x28,
	MD_AMY_LDGO = 0x29,
	MD_AMY_PNJP = 0x2A,
	MD_AMY_PNWT = 0x2B,
	MD_AMY_CAPT = 0x2C,
	MD_AMY_EVENT = 0x2D,
	MD_AMY_DOZA = 0x2E,
	MD_AMY_KILL = 0x2F,
	MD_AMY_S3A2_CART = 0x30,
	MD_AMY_CNADE_START = 0x31,
	MD_AMY_CNADE_LOOP = 0x32,
	MD_AMY_CNADE_END = 0x33,
	MD_AMY_CFUE = 0x34,
	MD_AMY_EDIT = 0x35,
};

enum MD_BIG
{
	MD_BIG_INIT = 0x0,
	MD_BIG_STND = 0x1,
	MD_BIG_WALK = 0x2,
	MD_BIG_1DWK = 0x3,
	MD_BIG_JUMP = 0x4,
	MD_BIG_SPRG = 0x5,
	MD_BIG_LNCH = 0x6,
	MD_BIG_PARA = 0x7,
	MD_BIG_FALL = 0x8,
	MD_BIG_STOP = 0x9,
	MD_BIG_PUSH = 0xA,
	MD_BIG_DAMG = 0xB,
	MD_BIG_CRSH = 0xC,
	MD_BIG_SLID = 0xD,
	MD_BIG_PLON = 0xE,
	MD_BIG_PICK = 0xF,
	MD_BIG_PUT_ = 0x10,
	MD_BIG_HOLD = 0x11,
	MD_BIG_TOCH = 0x12,
	MD_BIG_HWLK = 0x13,
	MD_BIG_THRW = 0x14,
	MD_BIG_HSTP = 0x15,
	MD_BIG_HFLL = 0x16,
	MD_BIG_HJMP = 0x17,
	MD_BIG_HSPR = 0x18,
	MD_BIG_HLNC = 0x19,
	MD_BIG_PULL = 0x1A,
	MD_BIG_THRU = 0x1B,
	MD_BIG_SHAK = 0x1C,
	MD_BIG_LDWT = 0x1D,
	MD_BIG_LDGO = 0x1E,
	MD_BIG_ATCK = 0x1F,
	MD_BIG_CAST = 0x20,
	MD_BIG_CAS1 = 0x21,
	MD_BIG_CAS2 = 0x22,
	MD_BIG_FISH = 0x23,
	MD_BIG_SAO_ = 0x24,
	MD_BIG_JOY_ = 0x25,
	MD_BIG_POSE = 0x26,
	MD_BIG_MISS = 0x27,
	MD_BIG_W_CAST = 0x28,
	MD_BIG_W_CAS1 = 0x29,
	MD_BIG_W_CAS2 = 0x2A,
	MD_BIG_W_FISH = 0x2B,
	MD_BIG_WSAO = 0x2C,
	MD_BIG_WJOY = 0x2D,
	MD_BIG_W_POSE = 0x2E,
	MD_BIG_W_WAIT = 0x2F,
	MD_BIG_W_SWIM = 0x30,
	MD_BIG_W_DIVE = 0x31,
	MD_BIG_ESHK = 0x32,
	MD_BIG_CNADE_START = 0x33,
	MD_BIG_CNADE_LOOP = 0x34,
	MD_BIG_CNADE_END = 0x35,
	MD_BIG_CFUE = 0x36,
	MD_BIG_CART = 0x37,
	MD_BIG_EVENT = 0x38,
	MD_BIG_DOZA = 0x39,
	MD_BIG_KILL = 0x3A,
	MD_BIG_EDIT = 0x3B,
};

enum MD_E102
{
	MD_E102_INIT = 0x0,
	MD_E102_STND = 0x1,
	MD_E102_WALK = 0x2,
	MD_E102_1DWK = 0x3,
	MD_E102_JUMP = 0x4,
	MD_E102_SPRG = 0x5,
	MD_E102_LNCH = 0x6,
	MD_E102_FALL = 0x7,
	MD_E102_STOP = 0x8,
	MD_E102_PUSH = 0x9,
	MD_E102_DAMG = 0xA,
	MD_E102_BACK = 0xB,
	MD_E102_CRSH = 0xC,
	MD_E102_SLID = 0xD,
	MD_E102_PLON = 0xE,
	MD_E102_PICK = 0xF,
	MD_E102_PUT_ = 0x10,
	MD_E102_HOLD = 0x11,
	MD_E102_TOCH = 0x12,
	MD_E102_HWLK = 0x13,
	MD_E102_THRW = 0x14,
	MD_E102_HSTP = 0x15,
	MD_E102_HFLL = 0x16,
	MD_E102_HJMP = 0x17,
	MD_E102_HSPR = 0x18,
	MD_E102_HLNC = 0x19,
	MD_E102_PULL = 0x1A,
	MD_E102_THRU = 0x1B,
	MD_E102_SHAK = 0x1C,
	MD_E102_PJUMP = 0x1D,
	MD_E102_PHJMP = 0x1E,
	MD_E102_GRUN = 0x1F,
	MD_E102_GRNH = 0x20,
	MD_E102_WRUN = 0x21,
	MD_E102_WRNH = 0x22,
	MD_E102_WJMP = 0x23,
	MD_E102_WJPH = 0x24,
	MD_E102_GJMP = 0x25,
	MD_E102_GJPH = 0x26,
	MD_E102_GSTP = 0x27,
	MD_E102_GHST = 0x28,
	MD_E102_AP_JUMP_I = 0x29,
	MD_E102_AP_JUMP = 0x2A,
	MD_E102_AP_FALL = 0x2B,
	MD_E102_AP_HOVER = 0x2C,
	MD_E102_AP_CHG_R = 0x2D,
	MD_E102_AP_CHG_W = 0x2E,
	MD_E102_LDWT = 0x2F,
	MD_E102_LDGO = 0x30,
	MD_E102_TIMEOVER1 = 0x31,
	MD_E102_TIMEOVER2 = 0x32,
	MD_E102_KILL = 0x33,
	MD_E102_KIME = 0x34,
	MD_E102_CART = 0x35,
	MD_E102_ESHK = 0x36,
	MD_E102_CNADE_START = 0x37,
	MD_E102_CNADE_LOOP = 0x38,
	MD_E102_CNADE_END = 0x39,
	MD_E102_CFUE = 0x3A,
	MD_E102_EVENT = 0x3B,
	MD_E102_EDIT = 0x3C,
};

// Legacy NJS_LIGHTs enum; LE_LIG_EV_DARK and LE_LIG_EV_CONS are used in E-100 series briefing cutscene when the lights turn off.
enum LE_LIG
{
	LE_LIG_0 = 0x0,
	LE_LIG_AS = 0x3,
	LE_LIG_FINALEGG = 0x2,
	LE_LIG_C0 = 0x2,
	LE_LIG_CHAOS = 0x2,
	LE_LIG_SPOT_HIGHWAY = 0x2,
	LE_LIG_EV_DARK = 0x2,
	LE_LIG_EV_CONS = 0x2,
};

// QueuedModelFlagsB in the original disasm
enum LATE
{
	LATE_WZ = 0x1,
	LATE_EASY = 0x2,
	LATE_LIG = 0x4,
	LATE_NO = 0x8,
	LATE_NCOMP = 0x10,
	LATE_MAT = 0x0,
};

enum AdvaStatEnum
{
	ADVA_STAT_REQWAIT = 0x0,
	ADVA_STAT_FADEIN = 0x1,
	ADVA_STAT_KEEP = 0x2,
	ADVA_STAT_FADEOUT = 0x3,
	ADVA_STAT_MAX = 0x4,
};

enum TrialActSbMdEnum
{
	TRIALACTSEL_SMD_STAY = 0x0,
	TRIALACTSEL_SMD_DECIDE = 0x1,
	TRIALACTSEL_SMD_NWAIT = 0x2,
	TRIALACTSEL_SMD_MAX = 0x3,
};

enum AvaStgEnum
{
	AVASTG_MR = 0x0,
	AVASTG_SS = 0x1,
	AVASTG_EC = 0x2,
	AVASTG_BEACH = 0x3,
	AVASTG_WINDY = 0x4,
	AVASTG_CASINO = 0x5,
	AVASTG_SNOW = 0x6,
	AVASTG_TWINKLEPARK = 0x7,
	AVASTG_HIGHWAY = 0x8,
	AVASTG_MOUNTAIN = 0x9,
	AVASTG_SKYDECK = 0xA,
	AVASTG_SHELTER = 0xB,
	AVASTG_RUIN = 0xC,
	AVASTG_FINAL = 0xD,
	AVASTG_SHOOTING1 = 0xE,
	AVASTG_SHOOTING2 = 0xF,
	AVASTG_SANDBOARD = 0x10,
	AVASTG_EC_C = 0x11,
	AVASTG_MG_CART = 0x12,
	AVASTG_CHAOS0 = 0x13,
	AVASTG_CHAOS2 = 0x14,
	AVASTG_CHAOS4 = 0x15,
	AVASTG_CHAOS6 = 0x16,
	AVASTG_EGGMOBILE1 = 0x17,
	AVASTG_EGGMOBILE2 = 0x18,
	AVASTG_EGGMOBILE3 = 0x19,
	AVASTG_VS_SONIC = 0x1A,
	AVASTG_VS_KNUCKLES = 0x1B,
	AVASTG_VS_MILES = 0x1C,
	AVASTG_VS_E102 = 0x1D,
	AVASTG_VS_ZERO = 0x1E,
	AVASTG_VS_E102B = 0x1F,
	AVASTG_VS_BOSS = 0x20,
	AVASTG_MAX = 0x21,
};

enum DiaTypeEnum
{
	DIA_TYPE_FILESEL = 0x0,
	DIA_TYPE_FILEDEL = 0x1,
	DIA_TYPE_MAINMENU = 0x2,
	DIA_TYPE_MAINMENU_NPUTI = 0x3,
	DIA_TYPE_TITLEMENU = 0x4,
	DIA_TYPE_TRIALACTSEL = 0x5,
	DIA_TYPE_MINIGAMESEL = 0x6,
	DIA_TYPE_CHARSEL1 = 0x7,
	DIA_TYPE_CHARSEL2 = 0x8,
	DIA_TYPE_CHARSEL3 = 0x9,
	DIA_TYPE_CHARSEL4 = 0xA,
	DIA_TYPE_OPT_MONOSTE = 0xB,
	DIA_TYPE_OPT_MSG = 0xC,
	DIA_TYPE_OPT_VOICE = 0xD,
	DIA_TYPE_OPT_TEXT = 0xE,
	DIA_TYPE_TVSETTING1 = 0xF,
	DIA_TYPE_SNDTEST = 0x10,
	DIA_TYPE_VMSNOMEM = 0x11,
	DIA_TYPE_OPT_VIBSEL = 0x12,
	DIA_TYPE_OPT_SNDOUT = 0x13,
	DIA_TYPE_FILE_CRC_ERR = 0x14,
	DIA_TYPE_FORMAT = 0x15,
	DIA_TYPE_NEW_FILESEL = 0x16,
	DIA_TYPE_MAINMENU_SUB_UN = 0x17,
	DIA_TYPE_MAINMENU_SUB = 0x18,
	DIA_TYPE_MAINMENU_SUB_DL = 0x19,
	DIA_TYPE_OPTIONMENU_SUB = 0x1A,
	DIA_TYPE_HOW_TO_PLAY = 0x1B,
	DIA_TYPE_LB_MENU = 0x1C,
	DIA_TYPE_MAINMENU_NDOWNLOAD = 0x1D,
	DIA_TYPE_MAINMENU_EXIT = 0x1E,
	DIA_TYPE_MAX = 0x1F,
};

enum TitleMenuSbMdEnum
{
	TITLEMENU_SMD_STAY = 0x0,
	TITLEMENU_SMD_DECIDE = 0x1,
	TITLEMENU_SMD_STAY_S = 0x2,
	TITLEMENU_SMD_TO_DEMO = 0x3,
	TITLEMENU_SMD_TO_DEMO2 = 0x4,
	TITLEMENU_SMD_TO_MAINMENU = 0x5,
	TITLEMENU_SMD_NWAIT = 0x6,
	TITLEMENU_SMD_MAX = 0x7,
};

enum TitleMenuEnum
{
	OPTION_MENU_HOW2PLAY = 0x0,
	OPTION_MENU_CONTROLS = 0x1,
	OPTION_MENU_OPTIONS = 0x2,
	OPTION_MENU_CREDITS = 0x3,
	OPTION_MENU_BACK = 0x4,
	OPTION_MENU_MAX = 0x5,
};

enum ChSbMdEnum
{
	CHSEL_SMD_STAY = 0x0,
	CHSEL_SMD_MOVING_L = 0x1,
	CHSEL_SMD_MOVING_R = 0x2,
	CHSEL_SMD_DECIDE = 0x3,
	CHSEL_SMD_DLG1 = 0x4,
	CHSEL_SMD_DLG2 = 0x5,
	CHSEL_SMD_DLG3 = 0x6,
	CHSEL_SMD_DLG4 = 0x7,
	CHSEL_SMD_DECIDE2 = 0x8,
	CHSEL_SMD_DECIDE2X = 0x9,
	CHSEL_SMD_NWAIT = 0xA,
	CHSEL_SMD_MAX = 0xB,
};

enum AdvDlgSelEnum
{
	ADVDLG_KAISHI = 0x0,
	ADVDLG_SETSUMEI = 0x1,
	ADVDLG_ENDING = 0x2,
	ADVDLG_CANCEL = 0x3,
	ADVDLG_MAX = 0x4,
};

enum DlgPnlStyleEnum
{
	DLG_PNLSTYLE_MARU = 0x0,
	DLG_PNLSTYLE_SIKAKU = 0x1,
	DLG_PNLSTYLE_MARU4 = 0x2,
	DLG_PNLSTYLE_MARUSO = 0x3,
	DLG_PNLSTYLE_SIKAKU2 = 0x4,
	DLG_PNLSTYLE_MARU2 = 0x5,
	DLG_PNLSTYLE_MAX = 0x6,
};

#endif /* SADXMODLOADER_SADXENUMSNEW_H */